import re
from typing import Tuple

AVOGADRO = 6.02214076e23

ATOMIC_SYMBOL = {
    0: "n",
    1: "H",
    2: "He",
    3: "Li",
    4: "Be",
    5: "B",
    6: "C",
    7: "N",
    8: "O",
    9: "F",
    10: "Ne",
    11: "Na",
    12: "Mg",
    13: "Al",
    14: "Si",
    15: "P",
    16: "S",
    17: "Cl",
    18: "Ar",
    19: "K",
    20: "Ca",
    21: "Sc",
    22: "Ti",
    23: "V",
    24: "Cr",
    25: "Mn",
    26: "Fe",
    27: "Co",
    28: "Ni",
    29: "Cu",
    30: "Zn",
    31: "Ga",
    32: "Ge",
    33: "As",
    34: "Se",
    35: "Br",
    36: "Kr",
    37: "Rb",
    38: "Sr",
    39: "Y",
    40: "Zr",
    41: "Nb",
    42: "Mo",
    43: "Tc",
    44: "Ru",
    45: "Rh",
    46: "Pd",
    47: "Ag",
    48: "Cd",
    49: "In",
    50: "Sn",
    51: "Sb",
    52: "Te",
    53: "I",
    54: "Xe",
    55: "Cs",
    56: "Ba",
    57: "La",
    58: "Ce",
    59: "Pr",
    60: "Nd",
    61: "Pm",
    62: "Sm",
    63: "Eu",
    64: "Gd",
    65: "Tb",
    66: "Dy",
    67: "Ho",
    68: "Er",
    69: "Tm",
    70: "Yb",
    71: "Lu",
    72: "Hf",
    73: "Ta",
    74: "W",
    75: "Re",
    76: "Os",
    77: "Ir",
    78: "Pt",
    79: "Au",
    80: "Hg",
    81: "Tl",
    82: "Pb",
    83: "Bi",
    84: "Po",
    85: "At",
    86: "Rn",
    87: "Fr",
    88: "Ra",
    89: "Ac",
    90: "Th",
    91: "Pa",
    92: "U",
    93: "Np",
    94: "Pu",
    95: "Am",
    96: "Cm",
    97: "Bk",
    98: "Cf",
    99: "Es",
    100: "Fm",
    101: "Md",
    102: "No",
    103: "Lr",
    104: "Rf",
    105: "Db",
    106: "Sg",
    107: "Bh",
    108: "Hs",
    109: "Mt",
    110: "Ds",
    111: "Rg",
    112: "Cn",
    113: "Nh",
    114: "Fl",
    115: "Mc",
    116: "Lv",
    117: "Ts",
    118: "Og",
}
ATOMIC_NUMBER = {value: key for key, value in ATOMIC_SYMBOL.items()}

ISOMER_NUMBER = {"": 0, "G": 0, "M": 1, "N": 2, "O": 3, "m1": 1, "m2": 2, "m3": 3}
ISOMER_NUMBER |= {k.upper(): v for k, v in ISOMER_NUMBER.items()}
ISOMER_NUMBER |= {k.lower(): v for k, v in ISOMER_NUMBER.items()}


def element(name):
    """Get the element name of a nuclide.

    Args:
        name (str): an nuclide's name

    Returns:
        str: The element's symbol.

    """
    z, _, _ = z_a_i(name)
    return ATOMIC_SYMBOL[z]


def z_a_i(name: str) -> Tuple[int]:
    """Convert a nuclide name to a tuple containing the nuclide's A, Z and E.

    Args:
        name (str): The name of the nuclide.

    Returns:
        tuple: A tuple containing the A, Z and I numbers

    """
    name_regex = r"([A-Za-z]+)[-_]*(\d+)[_]*(\w*)"
    groups = re.search(name_regex, name).groups()
    z = ATOMIC_NUMBER[groups[0].capitalize()]
    a = int(groups[1])
    i = ISOMER_NUMBER[groups[2]]
    return z, a, i


def atomic_mass(nuclide):
    if "_" in nuclide:
        return ATOMIC_MASS[nuclide.split("_")[0].capitalize()]
    return ATOMIC_MASS[nuclide]


ATOMIC_MASS = {
    "N1": 1.0086649159,
    "H1": 1.007825031898,
    "H2": 2.014101777844,
    "H3": 3.01604928132,
    "He3": 3.01602932197,
    "Li3": 3.030775,
    "H4": 4.026431867,
    "He4": 4.00260325413,
    "Li4": 4.027185561,
    "H5": 5.035311492,
    "He5": 5.012057224,
    "Li5": 5.0125378,
    "Be5": 5.03987,
    "H6": 6.044955437,
    "He6": 6.018885889,
    "Li6": 6.01512288742,
    "Be6": 6.0197264090000004,
    "B6": 6.0508,
    "H7": 7.052749,
    "He7": 7.027990652,
    "Li7": 7.01600343426,
    "Be7": 7.016928714,
    "B7": 7.029712,
    "He8": 8.033934388,
    "Li8": 8.022486244,
    "Be8": 8.005305102,
    "B8": 8.024607315,
    "C8": 8.037643039,
    "He9": 9.043946414,
    "Li9": 9.026790191,
    "Be9": 9.012183062,
    "B9": 9.013329645,
    "C9": 9.031037202,
    "He10": 10.052815306,
    "Li10": 10.035483453,
    "Be10": 10.013534692,
    "B10": 10.012936862,
    "C10": 10.016853217,
    "N10": 10.04165354,
    "Li11": 11.043723581,
    "Be11": 11.02166108,
    "B11": 11.009305166,
    "C11": 11.011432597,
    "N11": 11.026157593,
    "O11": 11.051249828,
    "Li12": 12.052613942,
    "Be12": 12.026922082,
    "B12": 12.014352638,
    "C12": 12.0,
    "N12": 12.01861318,
    "O12": 12.034367726,
    "Li13": 13.061171503,
    "Be13": 13.036134506,
    "B13": 13.017779981,
    "C13": 13.00335483534,
    "N13": 13.005738609,
    "O13": 13.024815435,
    "F13": 13.045121,
    "Be14": 14.04289292,
    "B14": 14.02540401,
    "C14": 14.00324198862,
    "N14": 14.00307400425,
    "O14": 14.008596706,
    "F14": 14.034315196,
    "Be15": 15.053490215,
    "B15": 15.031087023,
    "C15": 15.010599256,
    "N15": 15.00010889827,
    "O15": 15.003065636,
    "F15": 15.017785139,
    "Ne15": 15.043172977,
    "Be16": 16.061672036,
    "B16": 16.039841045,
    "C16": 16.014701255,
    "N16": 16.006101925,
    "O16": 15.99491461926,
    "F16": 16.011460278,
    "Ne16": 16.02575086,
    "B17": 17.046931399,
    "C17": 17.02257865,
    "N17": 17.008448876,
    "O17": 16.99913175595,
    "F17": 17.002095237,
    "Ne17": 17.017713962,
    "Na17": 17.037273,
    "B18": 18.055601683,
    "C18": 18.02675193,
    "N18": 18.014077563,
    "O18": 17.99915961214,
    "F18": 18.000937324,
    "Ne18": 18.005708696,
    "Na18": 18.026879388,
    "B19": 19.064166,
    "C19": 19.034797594,
    "N19": 19.017022389,
    "O19": 19.003577969,
    "F19": 18.99840316207,
    "Ne19": 19.001880906,
    "Na19": 19.013880264,
    "Mg19": 19.03417992,
    "B20": 20.074505644,
    "C20": 20.040261732,
    "N20": 20.023367295,
    "O20": 20.004075357,
    "F20": 19.999981252,
    "Ne20": 19.99244017525,
    "Na20": 20.007354301,
    "Mg20": 20.018763075,
    "B21": 21.084147485,
    "C21": 21.049,
    "N21": 21.027087573,
    "O21": 21.008654948,
    "F21": 20.999948893,
    "Ne21": 20.993846685,
    "Na21": 20.997654459,
    "Mg21": 21.011705764,
    "Al21": 21.029082,
    "C22": 22.05755399,
    "N22": 22.034100918,
    "O22": 22.009965744,
    "F22": 22.002998812,
    "Ne22": 21.991385113,
    "Na22": 21.994437547,
    "Mg22": 21.999570597,
    "Al22": 22.01954,
    "Si22": 22.036114,
    "C23": 23.06889,
    "N23": 23.039421,
    "O23": 23.015696686,
    "F23": 23.003526875,
    "Ne23": 22.994466905,
    "Na23": 22.98976928195,
    "Mg23": 22.994123768,
    "Al23": 23.007244351,
    "Si23": 23.025711,
    "N24": 24.05039,
    "O24": 24.019861,
    "F24": 24.00809937,
    "Ne24": 23.993610649,
    "Na24": 23.990963012,
    "Mg24": 23.985041689,
    "Al24": 23.999947598,
    "Si24": 24.01153543,
    "P24": 24.036522,
    "N25": 25.0601,
    "O25": 25.029338919,
    "F25": 25.012167727,
    "Ne25": 24.997814797,
    "Na25": 24.989953974,
    "Mg25": 24.985836966,
    "Al25": 24.990428308,
    "Si25": 25.004108798,
    "P25": 25.021675,
    "O26": 26.037210155,
    "F26": 26.020048065,
    "Ne26": 26.000516496,
    "Na26": 25.992634649,
    "Mg26": 25.982592972,
    "Al26": 25.986891876,
    "Si26": 25.992333818,
    "P26": 26.01178,
    "S26": 26.029716,
    "O27": 27.047955,
    "F27": 27.026981897,
    "Ne27": 27.007569462,
    "Na27": 26.994076408,
    "Mg27": 26.984340647,
    "Al27": 26.981538408,
    "Si27": 26.986704687,
    "P27": 26.999292499,
    "S27": 27.018777,
    "O28": 28.05591,
    "F28": 28.035860448,
    "Ne28": 28.012130767,
    "Na28": 27.998939,
    "Mg28": 27.983875426,
    "Al28": 27.981910009,
    "Si28": 27.97692653442,
    "P28": 27.99232646,
    "S28": 28.004372762,
    "Cl28": 28.030349,
    "F29": 29.043103,
    "Ne29": 29.019753,
    "Na29": 29.002877091,
    "Mg29": 28.988607163,
    "Al29": 28.980453164,
    "Si29": 28.97649466434,
    "P29": 28.981800368,
    "S29": 28.996678,
    "Cl29": 29.015053,
    "Ar29": 29.040761,
    "F30": 30.052561,
    "Ne30": 30.024992235,
    "Na30": 30.009097931,
    "Mg30": 29.990465454,
    "Al30": 29.982969171,
    "Si30": 29.973770137,
    "P30": 29.97831349,
    "S30": 29.98490677,
    "Cl30": 30.005018333,
    "Ar30": 30.023694,
    "F31": 31.061023,
    "Ne31": 31.033474816,
    "Na31": 31.013146654,
    "Mg31": 30.996648232,
    "Al31": 30.983949754,
    "Si31": 30.975363196,
    "P31": 30.97376199768,
    "S31": 30.979557002,
    "Cl31": 30.992448097,
    "Ar31": 31.012158,
    "K31": 31.03678,
    "Ne32": 32.03972,
    "Na32": 32.020011024,
    "Mg32": 31.999110138,
    "Al32": 31.988084338,
    "Si32": 31.974151538,
    "P32": 31.973907643,
    "S32": 31.97207117354,
    "Cl32": 31.985684605,
    "Ar32": 31.997637824,
    "K32": 32.023607,
    "Ne33": 33.049523,
    "Na33": 33.025529,
    "Mg33": 33.005327862,
    "Al33": 32.990877685,
    "Si33": 32.977976964,
    "P33": 32.971725692,
    "S33": 32.97145890862,
    "Cl33": 32.977451988,
    "Ar33": 32.989925545,
    "K33": 33.008095,
    "Ca33": 33.033312,
    "Ne34": 34.056728,
    "Na34": 34.03401,
    "Mg34": 34.008935455,
    "Al34": 33.996781924,
    "Si34": 33.978538045,
    "P34": 33.973645886,
    "S34": 33.967867011,
    "Cl34": 33.97376249,
    "Ar34": 33.980270092,
    "K34": 33.99869,
    "Ca34": 34.015985,
    "Na35": 35.040614,
    "Mg35": 35.01679,
    "Al35": 34.999759816,
    "Si35": 34.984550111,
    "P35": 34.973314045,
    "S35": 34.969032321,
    "Cl35": 34.968852694,
    "Ar35": 34.975257719,
    "K35": 34.988005406,
    "Ca35": 35.005572,
    "Sc35": 35.029093,
    "Na36": 36.049279,
    "Mg36": 36.021879,
    "Al36": 36.006388,
    "Si36": 35.986649271,
    "P36": 35.97825961,
    "S36": 35.967080692,
    "Cl36": 35.968306822,
    "Ar36": 35.967545106,
    "K36": 35.981301887,
    "Ca36": 35.993074388,
    "Sc36": 36.017338,
    "Na37": 37.057042,
    "Mg37": 37.030286265,
    "Al37": 37.010531,
    "Si37": 36.992945191,
    "P37": 36.979606942,
    "S37": 36.9711255,
    "Cl37": 36.965902573,
    "Ar37": 36.966776301,
    "K37": 36.97337589,
    "Ca37": 36.985897849,
    "Sc37": 37.004058,
    "Ti37": 37.027021,
    "Na38": 38.066458,
    "Mg38": 38.03658,
    "Al38": 38.017681,
    "Si38": 37.995523,
    "P38": 37.984303105,
    "S38": 37.9711633,
    "Cl38": 37.968010408,
    "Ar38": 37.962732102,
    "K38": 37.969081114,
    "Ca38": 37.976319223,
    "Sc38": 37.995438,
    "Ti38": 38.012206,
    "Na39": 39.075123,
    "Mg39": 39.045921,
    "Al39": 39.02307,
    "Si39": 39.002491,
    "P39": 38.986285865,
    "S39": 38.97513385,
    "Cl39": 38.968008151,
    "Ar39": 38.964313037,
    "K39": 38.96370648482,
    "Ca39": 38.970710811,
    "Sc39": 38.984784953,
    "Ti39": 39.002684,
    "V39": 39.02423,
    "Mg40": 40.053194,
    "Al40": 40.03094,
    "Si40": 40.006083641,
    "P40": 39.991262221,
    "S40": 39.975482561,
    "Cl40": 39.970415466,
    "Ar40": 39.96238312204,
    "K40": 39.963998165,
    "Ca40": 39.96259085,
    "Sc40": 39.977967275,
    "Ti40": 39.990345146,
    "V40": 40.013387,
    "Mg41": 41.062373,
    "Al41": 41.037134,
    "Si41": 41.014171,
    "P41": 40.994654,
    "S41": 40.979593451,
    "Cl41": 40.970684525,
    "Ar41": 40.96450057,
    "K41": 40.96182525611,
    "Ca41": 40.962277905,
    "Sc41": 40.969251163,
    "Ti41": 40.983148,
    "V41": 41.000333,
    "Cr41": 41.021911,
    "Al42": 42.045078,
    "Si42": 42.018078,
    "P42": 42.00117214,
    "S42": 41.9810651,
    "Cl42": 41.973342,
    "Ar42": 41.963045737,
    "K42": 41.962402305,
    "Ca42": 41.95861778,
    "Sc42": 41.965516686,
    "Ti42": 41.973049369,
    "V42": 41.99182,
    "Cr42": 42.007579,
    "Al43": 43.05182,
    "Si43": 43.026119,
    "P43": 43.005411,
    "S43": 42.986907635,
    "Cl43": 42.9740637,
    "Ar43": 42.965636056,
    "K43": 42.960734701,
    "Ca43": 42.958766381,
    "Sc43": 42.961150425,
    "Ti43": 42.96852842,
    "V43": 42.980766,
    "Cr43": 42.997885,
    "Mn43": 43.018647,
    "Si44": 44.031466,
    "P44": 44.011927,
    "S44": 43.990118846,
    "Cl44": 43.978014918,
    "Ar44": 43.964923814,
    "K44": 43.961586984,
    "Ca44": 43.955481489,
    "Sc44": 43.959402818,
    "Ti44": 43.959689936,
    "V44": 43.974440977,
    "Cr44": 43.985591,
    "Mn44": 44.008009,
    "Si45": 45.039818,
    "P45": 45.017134,
    "S45": 44.996414,
    "Cl45": 44.980394353,
    "Ar45": 44.968039731,
    "K45": 44.960691491,
    "Ca45": 44.95618627,
    "Sc45": 44.955907051,
    "Ti45": 44.958120758,
    "V45": 44.965768498,
    "Cr45": 44.97905,
    "Mn45": 44.994654,
    "Fe45": 45.015467,
    "P46": 46.02452,
    "S46": 46.000687,
    "Cl46": 45.985254926,
    "Ar46": 45.968039243999996,
    "K46": 45.961981584,
    "Ca46": 45.953687726,
    "Sc46": 45.955167034,
    "Ti46": 45.952626356,
    "V46": 45.960197389,
    "Cr46": 45.968360969,
    "Mn46": 45.986669,
    "Fe46": 46.001299,
    "P47": 47.030929,
    "S47": 47.00773,
    "Cl47": 46.989715,
    "Ar47": 46.972767112,
    "K47": 46.961661612,
    "Ca47": 46.954541134,
    "Sc47": 46.952402444,
    "Ti47": 46.951757491,
    "V47": 46.954903558,
    "Cr47": 46.962894995,
    "Mn47": 46.975774,
    "Fe47": 46.992346,
    "Co47": 47.011401,
    "S48": 48.013301,
    "Cl48": 47.995405,
    "Ar48": 47.976001,
    "K48": 47.965341184,
    "Ca48": 47.952522654,
    "Sc48": 47.952222903,
    "Ti48": 47.947940677,
    "V48": 47.9522509,
    "Cr48": 47.954029431,
    "Mn48": 47.96854876,
    "Fe48": 47.980667,
    "Co48": 48.001857,
    "Ni48": 48.019515,
    "S49": 49.021891,
    "Cl49": 49.000794,
    "Ar49": 48.981685,
    "K49": 48.968210753,
    "Ca49": 48.955662625,
    "Sc49": 48.950013159,
    "Ti49": 48.947864391,
    "V49": 48.948510509,
    "Cr49": 48.95133372,
    "Mn49": 48.95961335,
    "Fe49": 48.973429,
    "Co49": 48.989501,
    "Ni49": 49.009157,
    "Cl50": 50.008266,
    "Ar50": 49.985797,
    "K50": 49.972380015,
    "Ca50": 49.957499215,
    "Sc50": 49.952187437,
    "Ti50": 49.944785622,
    "V50": 49.947156681,
    "Cr50": 49.946042209,
    "Mn50": 49.954238157,
    "Fe50": 49.962988,
    "Co50": 49.981117,
    "Ni50": 49.996286,
    "Cl51": 51.015341,
    "Ar51": 50.993033,
    "K51": 50.975828664,
    "Ca51": 50.960995663,
    "Sc51": 50.953568838,
    "Ti51": 50.946609468,
    "V51": 50.943957664,
    "Cr51": 50.944765388,
    "Mn51": 50.94820877,
    "Fe51": 50.956855137,
    "Co51": 50.970647,
    "Ni51": 50.987493,
    "Cl52": 52.024004,
    "Ar52": 51.998519,
    "K52": 51.981602,
    "Ca52": 51.963213646,
    "Sc52": 51.95649617,
    "Ti52": 51.946883509,
    "V52": 51.944773636,
    "Cr52": 51.940504714,
    "Mn52": 51.94555909,
    "Fe52": 51.948113364,
    "Co52": 51.963130224,
    "Ni52": 51.975781,
    "Cu52": 51.997982,
    "Ar53": 53.00729,
    "K53": 52.9868,
    "Ca53": 52.968451,
    "Sc53": 52.958379173,
    "Ti53": 52.949670714,
    "V53": 52.94433494,
    "Cr53": 52.940646304,
    "Mn53": 52.941287497,
    "Fe53": 52.945305629,
    "Co53": 52.954203278,
    "Ni53": 52.96819,
    "Cu53": 52.985894,
    "Ar54": 54.013484,
    "K54": 53.994471,
    "Ca54": 53.972989,
    "Sc54": 53.963029359,
    "Ti54": 53.950892,
    "V54": 53.946432009,
    "Cr54": 53.938877359,
    "Mn54": 53.940355772,
    "Fe54": 53.939608189,
    "Co54": 53.948459075,
    "Ni54": 53.957833,
    "Cu54": 53.977198,
    "Zn54": 53.993879,
    "K55": 55.000505,
    "Ca55": 54.979978,
    "Sc55": 54.966889637,
    "Ti55": 54.955091,
    "V55": 54.947262,
    "Cr55": 54.940836637,
    "Mn55": 54.93804304,
    "Fe55": 54.938291158,
    "Co55": 54.941996416,
    "Ni55": 54.951329846,
    "Cu55": 54.966038,
    "Zn55": 54.984681,
    "K56": 56.008567,
    "Ca56": 55.985496,
    "Sc56": 55.972607611,
    "Ti56": 55.957677675,
    "V56": 55.950420082,
    "Cr56": 55.940648977,
    "Mn56": 55.938902816,
    "Fe56": 55.934935537,
    "Co56": 55.939838032,
    "Ni56": 55.942127761,
    "Cu56": 55.958529278,
    "Zn56": 55.972743,
    "Ga56": 55.995878,
    "K57": 57.015169,
    "Ca57": 56.992958,
    "Sc57": 56.977047999999996,
    "Ti57": 56.963068098,
    "V57": 56.952297,
    "Cr57": 56.943612112,
    "Mn57": 56.938285944,
    "Fe57": 56.93539195,
    "Co57": 56.936289819,
    "Ni57": 56.939791394,
    "Cu57": 56.949211686,
    "Zn57": 56.965056,
    "Ga57": 56.983457,
    "K58": 58.023543,
    "Ca58": 57.998357,
    "Sc58": 57.983382,
    "Ti58": 57.966808519,
    "V58": 57.956595985,
    "Cr58": 57.944184501,
    "Mn58": 57.940066643,
    "Fe58": 57.933273575,
    "Co58": 57.935751292,
    "Ni58": 57.93534165,
    "Cu58": 57.944532283,
    "Zn58": 57.954590296,
    "Ga58": 57.974728999999996,
    "Ge58": 57.991863,
    "K59": 59.030864,
    "Ca59": 59.006237,
    "Sc59": 58.988374,
    "Ti59": 58.972217,
    "V59": 58.959623343,
    "Cr59": 58.948345426,
    "Mn59": 58.940391111,
    "Fe59": 58.934873492,
    "Co59": 58.933193523999996,
    "Ni59": 58.934345442,
    "Cu59": 58.939496713,
    "Zn59": 58.949311886,
    "Ga59": 58.963757,
    "Ge59": 58.982426,
    "Ca60": 60.011809,
    "Sc60": 59.995115,
    "Ti60": 59.976275,
    "V60": 59.964479215,
    "Cr60": 59.949641656,
    "Mn60": 59.943136574,
    "Fe60": 59.934070249,
    "Co60": 59.933815536,
    "Ni60": 59.930785129,
    "Cu60": 59.937363787,
    "Zn60": 59.941841317,
    "Ga60": 59.957498,
    "Ge60": 59.970445,
    "As60": 59.993945,
    "Ca61": 61.020408,
    "Sc61": 61.000537,
    "Ti61": 60.982426,
    "V61": 60.967603529,
    "Cr61": 60.95437813,
    "Mn61": 60.944452541,
    "Fe61": 60.936746241,
    "Co61": 60.932476031,
    "Ni61": 60.931054819,
    "Cu61": 60.933457375,
    "Zn61": 60.939506964,
    "Ga61": 60.949398861,
    "Ge61": 60.963725,
    "As61": 60.981535,
    "Sc62": 62.007848,
    "Ti62": 61.986903,
    "V62": 61.972932556,
    "Cr62": 61.95614292,
    "Mn62": 61.947907384,
    "Fe62": 61.936791809,
    "Co62": 61.934058198,
    "Ni62": 61.928344753,
    "Cu62": 61.932594803,
    "Zn62": 61.934333359,
    "Ga62": 61.944189639,
    "Ge62": 61.954761,
    "As62": 61.973784,
    "Sc63": 63.014031,
    "Ti63": 62.993709,
    "V63": 62.976661,
    "Cr63": 62.961161,
    "Mn63": 62.949664672,
    "Fe63": 62.940272698,
    "Co63": 62.93359963,
    "Ni63": 62.929669021,
    "Cu63": 62.929597119,
    "Zn63": 62.93321114,
    "Ga63": 62.939294194,
    "Ge63": 62.949628,
    "As63": 62.964036,
    "Se63": 62.981911,
    "Ti64": 63.998411,
    "V64": 63.98248,
    "Cr64": 63.963886,
    "Mn64": 63.953849369,
    "Fe64": 63.940987761,
    "Co64": 63.935810176,
    "Ni64": 63.927966228,
    "Cu64": 63.929764001,
    "Zn64": 63.929141776,
    "Ga64": 63.936840366,
    "Ge64": 63.941689912,
    "As64": 63.95756,
    "Se64": 63.971165,
    "Ti65": 65.005593,
    "V65": 64.986999,
    "Cr65": 64.969608,
    "Mn65": 64.956019749,
    "Fe65": 64.945015323,
    "Co65": 64.936462071,
    "Ni65": 64.930084585,
    "Cu65": 64.927789476,
    "Zn65": 64.929240534,
    "Ga65": 64.932734424,
    "Ge65": 64.939368136,
    "As65": 64.949611,
    "Se65": 64.964552,
    "Br65": 64.982297,
    "V66": 65.993237,
    "Cr66": 65.973011,
    "Mn66": 65.960546833,
    "Fe66": 65.946249958,
    "Co66": 65.939442943,
    "Ni66": 65.929139333,
    "Cu66": 65.928868804,
    "Zn66": 65.926033639,
    "Ga66": 65.931589766,
    "Ge66": 65.933862124,
    "As66": 65.944148778,
    "Se66": 65.955276,
    "Br66": 65.974697,
    "V67": 66.998128,
    "Cr67": 66.979313,
    "Mn67": 66.96395,
    "Fe67": 66.95093,
    "Co67": 66.940609625,
    "Ni67": 66.931569413,
    "Cu67": 66.92772949,
    "Zn67": 66.927127422,
    "Ga67": 66.928202276,
    "Ge67": 66.932716999,
    "As67": 66.93925111,
    "Se67": 66.949994,
    "Br67": 66.965078,
    "Kr67": 66.983305,
    "Cr68": 67.983156,
    "Mn68": 67.968953,
    "Fe68": 67.952875,
    "Co68": 67.944559401,
    "Ni68": 67.931868787,
    "Cu68": 67.929610887,
    "Zn68": 67.924844232,
    "Ga68": 67.927980161,
    "Ge68": 67.928095305,
    "As68": 67.936774127,
    "Se68": 67.941825236,
    "Br68": 67.958356,
    "Kr68": 67.972489,
    "Cr69": 68.989662,
    "Mn69": 68.972775,
    "Fe69": 68.957918,
    "Co69": 68.945909,
    "Ni69": 68.935610267,
    "Cu69": 68.929429267,
    "Zn69": 68.92655036,
    "Ga69": 68.925573528,
    "Ge69": 68.927964467,
    "As69": 68.932246289,
    "Se69": 68.939414845,
    "Br69": 68.95033841,
    "Kr69": 68.965496,
    "Cr70": 69.993945,
    "Mn70": 69.978046,
    "Fe70": 69.960397,
    "Co70": 69.9500534,
    "Ni70": 69.9364313,
    "Cu70": 69.932392078,
    "Zn70": 69.925319175,
    "Ga70": 69.926021914,
    "Ge70": 69.924248542,
    "As70": 69.930934642,
    "Se70": 69.933515521,
    "Br70": 69.944792321,
    "Kr70": 69.955877,
    "Mn71": 70.982158,
    "Fe71": 70.965722,
    "Co71": 70.952366923,
    "Ni71": 70.940518962,
    "Cu71": 70.932676831,
    "Zn71": 70.927719578,
    "Ga71": 70.924702554,
    "Ge71": 70.92495212,
    "As71": 70.927113594,
    "Se71": 70.932209431,
    "Br71": 70.939342153,
    "Kr71": 70.950265695,
    "Rb71": 70.965335,
    "Mn72": 71.988009,
    "Fe72": 71.968599,
    "Co72": 71.956736,
    "Ni72": 71.941785924,
    "Cu72": 71.935820306,
    "Zn72": 71.926842806,
    "Ga72": 71.926367452,
    "Ge72": 71.922075824,
    "As72": 71.926752291,
    "Se72": 71.927140506,
    "Br72": 71.936594606,
    "Kr72": 71.942092406,
    "Rb72": 71.958851,
    "Mn73": 72.992807,
    "Fe73": 72.974246,
    "Co73": 72.959238,
    "Ni73": 72.946206681,
    "Cu73": 72.936674376,
    "Zn73": 72.92958258,
    "Ga73": 72.92517468,
    "Ge73": 72.923458954,
    "As73": 72.923829086,
    "Se73": 72.926754881,
    "Br73": 72.931673441,
    "Kr73": 72.939289193,
    "Rb73": 72.950604506,
    "Sr73": 72.9657,
    "Fe74": 73.977821,
    "Co74": 73.963993,
    "Ni74": 73.947718,
    "Cu74": 73.93987486,
    "Zn74": 73.92940726,
    "Ga74": 73.926945725,
    "Ge74": 73.92117776,
    "As74": 73.923928596,
    "Se74": 73.922475933,
    "Br74": 73.929910279,
    "Kr74": 73.933084016,
    "Rb74": 73.944265867,
    "Sr74": 73.95617,
    "Fe75": 74.984219,
    "Co75": 74.967192,
    "Ni75": 74.952506,
    "Cu75": 74.941523817,
    "Zn75": 74.932840244,
    "Ga75": 74.926504484,
    "Ge75": 74.92285837,
    "As75": 74.921594562,
    "Se75": 74.92252287,
    "Br75": 74.925810566,
    "Kr75": 74.930945744,
    "Rb75": 74.9385732,
    "Sr75": 74.949952767,
    "Y75": 74.96584,
    "Fe76": 75.988631,
    "Co76": 75.972453,
    "Ni76": 75.954707,
    "Cu76": 75.945268974,
    "Zn76": 75.933114956,
    "Ga76": 75.928827624,
    "Ge76": 75.921402725,
    "As76": 75.922392011,
    "Se76": 75.919213702,
    "Br76": 75.924541574,
    "Kr76": 75.925910743,
    "Rb76": 75.935073031,
    "Sr76": 75.94176276,
    "Y76": 75.958937,
    "Co77": 76.976479,
    "Ni77": 76.959903,
    "Cu77": 76.947543599,
    "Zn77": 76.936887197,
    "Ga77": 76.929154299,
    "Ge77": 76.923549843,
    "As77": 76.920647555,
    "Se77": 76.91991415,
    "Br77": 76.921379193,
    "Kr77": 76.924669999,
    "Rb77": 76.930401599,
    "Sr77": 76.937945454,
    "Y77": 76.950146,
    "Zr77": 76.966076,
    "Co78": 77.983553,
    "Ni78": 77.962555,
    "Cu78": 77.951916524,
    "Zn78": 77.938289204,
    "Ga78": 77.931610854,
    "Ge78": 77.922852911,
    "As78": 77.921827771,
    "Se78": 77.917309244,
    "Br78": 77.921145858,
    "Kr78": 77.920366341,
    "Rb78": 77.928141866,
    "Sr78": 77.932179979,
    "Y78": 77.94399,
    "Zr78": 77.956146,
    "Ni79": 78.969769,
    "Cu79": 78.9544731,
    "Zn79": 78.942638067,
    "Ga79": 78.932851582,
    "Ge79": 78.925359506,
    "As79": 78.920948419,
    "Se79": 78.918499252,
    "Br79": 78.918337574,
    "Kr79": 78.920082919,
    "Rb79": 78.923990095,
    "Sr79": 78.929704692,
    "Y79": 78.937946,
    "Zr79": 78.94979,
    "Nb79": 78.966022,
    "Ni80": 79.975051,
    "Cu80": 79.960623,
    "Zn80": 79.944552929,
    "Ga80": 79.936420773,
    "Ge80": 79.925350773,
    "As80": 79.92247444,
    "Se80": 79.916521761,
    "Br80": 79.918529784,
    "Kr80": 79.91637794,
    "Rb80": 79.922516442,
    "Sr80": 79.924517538,
    "Y80": 79.93435475,
    "Zr80": 79.941213,
    "Nb80": 79.958754,
    "Ni81": 80.982727,
    "Cu81": 80.965743,
    "Zn81": 80.950402617,
    "Ga81": 80.938133841,
    "Ge81": 80.928832941,
    "As81": 80.922132288,
    "Se81": 80.917993019,
    "Br81": 80.916288197,
    "Kr81": 80.916589703,
    "Rb81": 80.9189939,
    "Sr81": 80.923211393,
    "Y81": 80.929454283,
    "Zr81": 80.938245,
    "Nb81": 80.95023,
    "Mo81": 80.966226,
    "Ni82": 81.988492,
    "Cu82": 81.972378,
    "Zn82": 81.954574097,
    "Ga82": 81.943176531,
    "Ge82": 81.929774031,
    "As82": 81.924738731,
    "Se82": 81.916699531,
    "Br82": 81.916801752,
    "Kr82": 81.91348115368,
    "Rb82": 81.918209023,
    "Sr82": 81.918399845,
    "Y82": 81.926930189,
    "Zr82": 81.931707497,
    "Nb82": 81.94438,
    "Mo82": 81.956661,
    "Cu83": 82.97811,
    "Zn83": 82.961041,
    "Ga83": 82.9471203,
    "Ge83": 82.9345391,
    "As83": 82.9252069,
    "Se83": 82.919118604,
    "Br83": 82.915175285,
    "Kr83": 82.914126516,
    "Rb83": 82.915114181,
    "Sr83": 82.917554372,
    "Y83": 82.922484026,
    "Zr83": 82.929240926,
    "Nb83": 82.93815,
    "Mo83": 82.950252,
    "Tc83": 82.966377,
    "Cu84": 83.985271,
    "Zn84": 83.965829,
    "Ga84": 83.952663,
    "Ge84": 83.93757509,
    "As84": 83.92930329000001,
    "Se84": 83.918466761,
    "Br84": 83.916496417,
    "Kr84": 83.91149772708,
    "Rb84": 83.914375223,
    "Sr84": 83.913419118,
    "Y84": 83.92067106,
    "Zr84": 83.923325663,
    "Nb84": 83.934305711,
    "Mo84": 83.941846,
    "Tc84": 83.959527,
    "Zn85": 84.973054,
    "Ga85": 84.957333,
    "Ge85": 84.942969658,
    "As85": 84.932163658,
    "Se85": 84.922260758,
    "Br85": 84.915645758,
    "Kr85": 84.91252726,
    "Rb85": 84.91178973604,
    "Sr85": 84.912932041,
    "Y85": 84.916433039,
    "Zr85": 84.921443199,
    "Nb85": 84.928845836,
    "Mo85": 84.938260736,
    "Tc85": 84.950778,
    "Ru85": 84.967117,
    "Zn86": 85.978463,
    "Ga86": 85.963757,
    "Ge86": 85.946967,
    "As86": 85.936701532,
    "Se86": 85.924311732,
    "Br86": 85.918805432,
    "Kr86": 85.91061062468,
    "Rb86": 85.911167443,
    "Sr86": 85.90926072473,
    "Y86": 85.914886095,
    "Zr86": 85.916296814,
    "Nb86": 85.925781536,
    "Mo86": 85.931174092,
    "Tc86": 85.944637,
    "Ru86": 85.957305,
    "Ga87": 86.969007,
    "Ge87": 86.953204,
    "As87": 86.940291716,
    "Se87": 86.928688616,
    "Br87": 86.920674016,
    "Kr87": 86.913354759,
    "Rb87": 86.909180529,
    "Sr87": 86.90887749454,
    "Y87": 86.9108761,
    "Zr87": 86.914817338,
    "Nb87": 86.920692473,
    "Mo87": 86.928196198,
    "Tc87": 86.938067185,
    "Ru87": 86.950907,
    "Ga88": 87.975963,
    "Ge88": 87.957574,
    "As88": 87.94584,
    "Se88": 87.93141749,
    "Br88": 87.92408329,
    "Kr88": 87.914447879,
    "Rb88": 87.91131559,
    "Sr88": 87.905612253,
    "Y88": 87.909501274,
    "Zr88": 87.910220715,
    "Nb88": 87.918226476,
    "Mo88": 87.921967779,
    "Tc88": 87.933794211,
    "Ru88": 87.941664,
    "Rh88": 87.960429,
    "Ge89": 88.96453,
    "As89": 88.950048,
    "Se89": 88.936669058,
    "Br89": 88.926704558,
    "Kr89": 88.917835449,
    "Rb89": 88.912278136,
    "Sr89": 88.907450808,
    "Y89": 88.905838156,
    "Zr89": 88.908879751,
    "Nb89": 88.913444696,
    "Mo89": 88.919468149,
    "Tc89": 88.927648649,
    "Ru89": 88.937337849,
    "Rh89": 88.950992,
    "Ge90": 89.969436,
    "As90": 89.955995,
    "Se90": 89.940096,
    "Br90": 89.931292848,
    "Kr90": 89.919527929,
    "Rb90": 89.914797557,
    "Sr90": 89.90772787,
    "Y90": 89.907141749,
    "Zr90": 89.904698755,
    "Nb90": 89.911259201,
    "Mo90": 89.91393127,
    "Tc90": 89.924073919,
    "Ru90": 89.930344378,
    "Rh90": 89.944569,
    "Pd90": 89.95737,
    "As91": 90.960816,
    "Se91": 90.9457,
    "Br91": 90.934398617,
    "Kr91": 90.923806309,
    "Rb91": 90.916537261,
    "Sr91": 90.910195942,
    "Y91": 90.907298048,
    "Zr91": 90.905640205,
    "Nb91": 90.906990256,
    "Mo91": 90.91174519,
    "Tc91": 90.918424972,
    "Ru91": 90.92674153,
    "Rh91": 90.937123,
    "Pd91": 90.950435,
    "As92": 91.967386,
    "Se92": 91.94984,
    "Br92": 91.939631595,
    "Kr92": 91.926173092,
    "Rb92": 91.919728477,
    "Sr92": 91.911038222,
    "Y92": 91.908945752,
    "Zr92": 91.905035336,
    "Nb92": 91.90718858,
    "Mo92": 91.906807153,
    "Tc92": 91.915269777,
    "Ru92": 91.920234373,
    "Rh92": 91.932367692,
    "Pd92": 91.941192225,
    "Ag92": 91.95971,
    "Se93": 92.956135,
    "Br93": 92.94322,
    "Kr93": 92.931147172,
    "Rb93": 92.922039334,
    "Sr93": 92.914024314,
    "Y93": 92.909578434,
    "Zr93": 92.906470661,
    "Nb93": 92.90637317,
    "Mo93": 92.906808772,
    "Tc93": 92.910245147,
    "Ru93": 92.917104442,
    "Rh93": 92.925912778,
    "Pd93": 92.936680426,
    "Ag93": 92.950188,
    "Se94": 93.96049,
    "Br94": 93.948846,
    "Kr94": 93.934140452,
    "Rb94": 93.926394819,
    "Sr94": 93.915355641,
    "Y94": 93.911592062,
    "Zr94": 93.906312523,
    "Nb94": 93.907279001,
    "Mo94": 93.905083586,
    "Tc94": 93.909652319,
    "Ru94": 93.91134286,
    "Rh94": 93.92173045,
    "Pd94": 93.929036286,
    "Ag94": 93.943744,
    "Cd94": 93.956586,
    "Se95": 94.9673,
    "Br95": 94.952925,
    "Kr95": 94.939710922,
    "Rb95": 94.929263849,
    "Sr95": 94.919358282,
    "Y95": 94.912819697,
    "Zr95": 94.908040276,
    "Nb95": 94.90683111,
    "Mo95": 94.905837436,
    "Tc95": 94.907652281,
    "Ru95": 94.910404415,
    "Rh95": 94.915897893,
    "Pd95": 94.924888506,
    "Ag95": 94.935688,
    "Cd95": 94.949483,
    "Br96": 95.95898,
    "Kr96": 95.943014473,
    "Rb96": 95.934133398,
    "Sr96": 95.921719045,
    "Y96": 95.915909305,
    "Zr96": 95.908277615,
    "Nb96": 95.908101586,
    "Mo96": 95.90467477,
    "Tc96": 95.907866675,
    "Ru96": 95.90758891,
    "Rh96": 95.914451705,
    "Pd96": 95.918213739,
    "Ag96": 95.930743903,
    "Cd96": 95.940341,
    "In96": 95.959109,
    "Br97": 96.963499,
    "Kr97": 96.949088782,
    "Rb97": 96.937177117,
    "Sr97": 96.926375621,
    "Y97": 96.918286702,
    "Zr97": 96.910963802,
    "Nb97": 96.908101622,
    "Mo97": 96.906016903,
    "Tc97": 96.90636072,
    "Ru97": 96.907545776,
    "Rh97": 96.911327872,
    "Pd97": 96.916471985,
    "Ag97": 96.9238814,
    "Cd97": 96.934799343,
    "In97": 96.949125,
    "Br98": 97.969887,
    "Kr98": 97.952635,
    "Rb98": 97.941632317,
    "Sr98": 97.928692636,
    "Y98": 97.922394841,
    "Zr98": 97.912740448,
    "Nb98": 97.910332645,
    "Mo98": 97.905403609,
    "Tc98": 97.907211206,
    "Ru98": 97.905286709,
    "Rh98": 97.910707734,
    "Pd98": 97.912698335,
    "Ag98": 97.92155997,
    "Cd98": 97.927389315,
    "In98": 97.942129,
    "Kr99": 98.958776,
    "Rb99": 98.94511919,
    "Sr99": 98.932883604,
    "Y99": 98.924160839,
    "Zr99": 98.916675081,
    "Nb99": 98.911609377,
    "Mo99": 98.907707299,
    "Tc99": 98.906249681,
    "Ru99": 98.905930284,
    "Rh99": 98.908121241,
    "Pd99": 98.911773073,
    "Ag99": 98.917645766,
    "Cd99": 98.924925845,
    "In99": 98.93411,
    "Sn99": 98.948495,
    "Kr100": 99.962995,
    "Rb100": 99.950331532,
    "Sr100": 99.93578327,
    "Y100": 99.927727678,
    "Zr100": 99.918010499,
    "Nb100": 99.914340578,
    "Mo100": 99.907467982,
    "Tc100": 99.907652715,
    "Ru100": 99.90421046,
    "Rh100": 99.908114147,
    "Pd100": 99.908520438,
    "Ag100": 99.916115443,
    "Cd100": 99.920348829,
    "In100": 99.931101929,
    "Sn100": 99.938648944,
    "Kr101": 100.969318,
    "Rb101": 100.954302,
    "Sr101": 100.940606264,
    "Y101": 100.930160817,
    "Zr101": 100.921458454,
    "Nb101": 100.915306508,
    "Mo101": 100.910337648,
    "Tc101": 100.907305271,
    "Ru101": 100.905573086,
    "Rh101": 100.906158903,
    "Pd101": 100.908284824,
    "Ag101": 100.912683951,
    "Cd101": 100.918586209,
    "In101": 100.926414025,
    "Sn101": 100.935259252,
    "Rb102": 101.960008,
    "Sr102": 101.944004679,
    "Y102": 101.934328471,
    "Zr102": 101.923154181,
    "Nb102": 101.918090447,
    "Mo102": 101.910293725,
    "Tc102": 101.909207239,
    "Ru102": 101.904340312,
    "Rh102": 101.906834282,
    "Pd102": 101.905632292,
    "Ag102": 101.911704538,
    "Cd102": 101.914481797,
    "In102": 101.924105911,
    "Sn102": 101.930289525,
    "Sb102": 101.945142,
    "Rb103": 102.964401,
    "Sr103": 102.949243,
    "Y103": 102.937243796,
    "Zr103": 102.927204054,
    "Nb103": 102.919453416,
    "Mo103": 102.913091954,
    "Tc103": 102.90917396,
    "Ru103": 102.906314846,
    "Rh103": 102.905494081,
    "Pd103": 102.906111074,
    "Ag103": 102.908960558,
    "Cd103": 102.913416922,
    "In103": 102.91987883,
    "Sn103": 102.927973,
    "Sb103": 102.939162,
    "Rb104": 103.970531,
    "Sr104": 103.953022,
    "Y104": 103.941943,
    "Zr104": 103.929449193,
    "Nb104": 103.922907728,
    "Mo104": 103.913747443,
    "Tc104": 103.911433718,
    "Ru104": 103.905425312,
    "Rh104": 103.906645309,
    "Pd104": 103.904030393,
    "Ag104": 103.908623715,
    "Cd104": 103.909856228,
    "In104": 103.918214538,
    "Sn104": 103.923105195,
    "Sb104": 103.936344,
    "Te104": 103.946723408,
    "Sr105": 104.959001,
    "Y105": 104.945711,
    "Zr105": 104.934021832,
    "Nb105": 104.924942577,
    "Mo105": 104.91698198899999,
    "Tc105": 104.911662024,
    "Ru105": 104.907745478,
    "Rh105": 104.905687787,
    "Pd105": 104.905079479,
    "Ag105": 104.906525604,
    "Cd105": 104.909463893,
    "In105": 104.914502322,
    "Sn105": 104.921268421,
    "Sb105": 104.931276547,
    "Te105": 104.943304516,
    "Sr106": 105.963177,
    "Y106": 105.950842,
    "Zr106": 105.93693,
    "Nb106": 105.928928505,
    "Mo106": 105.918273231,
    "Tc106": 105.914356674,
    "Ru106": 105.907328181,
    "Rh106": 105.907285879,
    "Pd106": 105.903480287,
    "Ag106": 105.906663499,
    "Cd106": 105.906459791,
    "In106": 105.913463596,
    "Sn106": 105.916957394,
    "Sb106": 105.928637979,
    "Te106": 105.937498521,
    "I106": 105.953516,
    "Sr107": 106.969672,
    "Y107": 106.954943,
    "Zr107": 106.942007,
    "Nb107": 106.931589685,
    "Mo107": 106.92211977,
    "Tc107": 106.915458437,
    "Ru107": 106.909969837,
    "Rh107": 106.906747975,
    "Pd107": 106.905128058,
    "Ag107": 106.905091509,
    "Cd107": 106.906612049,
    "In107": 106.910287497,
    "Sn107": 106.915713649,
    "Sb107": 106.924150621,
    "Te107": 106.934882,
    "I107": 106.946935,
    "Y108": 107.960515,
    "Zr108": 107.945303,
    "Nb108": 107.936075604,
    "Mo108": 107.924047508,
    "Tc108": 107.918493493,
    "Ru108": 107.910185793,
    "Rh108": 107.908715304,
    "Pd108": 107.903891806,
    "Ag108": 107.905950245,
    "Cd108": 107.904183588,
    "In108": 107.909693654,
    "Sn108": 107.91189429,
    "Sb108": 107.922226731,
    "Te108": 107.929380469,
    "I108": 107.943348,
    "Xe108": 107.954232285,
    "Y109": 108.965131,
    "Zr109": 108.950907,
    "Nb109": 108.939141,
    "Mo109": 108.928438318,
    "Tc109": 108.920254107,
    "Ru109": 108.913323707,
    "Rh109": 108.908749555,
    "Pd109": 108.905950576,
    "Ag109": 108.904755778,
    "Cd109": 108.904986697,
    "In109": 108.907149679,
    "Sn109": 108.911292857,
    "Sb109": 108.918141203,
    "Te109": 108.927304532,
    "I109": 108.938086022,
    "Xe109": 108.950434955,
    "Zr110": 109.954675,
    "Nb110": 109.943843,
    "Mo110": 109.930717956,
    "Tc110": 109.923741263,
    "Ru110": 109.914038501,
    "Rh110": 109.911079745,
    "Pd110": 109.905172878,
    "Ag110": 109.906110724,
    "Cd110": 109.90300747,
    "In110": 109.907170674,
    "Sn110": 109.907844835,
    "Sb110": 109.916854283,
    "Te110": 109.922458102,
    "I110": 109.935085102,
    "Xe110": 109.944258759,
    "Zr111": 110.960837,
    "Nb111": 110.947439,
    "Mo111": 110.935651966,
    "Tc111": 110.925898966,
    "Ru111": 110.917567566,
    "Rh111": 110.911643164,
    "Pd111": 110.907690358,
    "Ag111": 110.905296827,
    "Cd111": 110.904183776,
    "In111": 110.905107236,
    "Sn111": 110.907741143,
    "Sb111": 110.913218187,
    "Te111": 110.921000587,
    "I111": 110.930269236,
    "Xe111": 110.94147,
    "Cs111": 110.953945,
    "Zr112": 111.965196,
    "Nb112": 111.952689,
    "Mo112": 111.938293,
    "Tc112": 111.929941658,
    "Ru112": 111.918806922,
    "Rh112": 111.914405199,
    "Pd112": 111.907330557,
    "Ag112": 111.907048548,
    "Cd112": 111.902763896,
    "In112": 111.905538718,
    "Sn112": 111.904824894,
    "Sb112": 111.912399903,
    "Te112": 111.916727848,
    "I112": 111.928004548,
    "Xe112": 111.935559068,
    "Cs112": 111.950172,
    "Zr113": 112.971723,
    "Nb113": 112.956833,
    "Mo113": 112.943478,
    "Tc113": 112.932569032,
    "Ru113": 112.922846729,
    "Rh113": 112.915440212,
    "Pd113": 112.910261912,
    "Ag113": 112.906572865,
    "Cd113": 112.904408105,
    "In113": 112.904060451,
    "Sn113": 112.905175857,
    "Sb113": 112.909374664,
    "Te113": 112.915891,
    "I113": 112.923650062,
    "Xe113": 112.933221663,
    "Cs113": 112.944428484,
    "Ba113": 112.95737,
    "Nb114": 113.962469,
    "Mo114": 113.946666,
    "Tc114": 113.93709,
    "Ru114": 113.92461443,
    "Rh114": 113.91872168,
    "Pd114": 113.91036943,
    "Ag114": 113.908823029,
    "Cd114": 113.903364998,
    "In114": 113.904916405,
    "Sn114": 113.90278013,
    "Sb114": 113.909289155,
    "Te114": 113.91208782,
    "I114": 113.9220189,
    "Xe114": 113.927980329,
    "Cs114": 113.941292244,
    "Ba114": 113.950718489,
    "Nb115": 114.966849,
    "Mo115": 114.952174,
    "Tc115": 114.9401,
    "Ru115": 114.929033049,
    "Rh115": 114.920311649,
    "Pd115": 114.913659333,
    "Ag115": 114.908767445,
    "Cd115": 114.905437426,
    "In115": 114.903878772,
    "Sn115": 114.903344695,
    "Sb115": 114.906598,
    "Te115": 114.911902,
    "I115": 114.918048,
    "Xe115": 114.926293943,
    "Cs115": 114.93591,
    "Ba115": 114.947482,
    "Nb116": 115.972914,
    "Mo116": 115.955759,
    "Tc116": 115.94502,
    "Ru116": 115.931219191,
    "Rh116": 115.92406206,
    "Pd116": 115.914297872,
    "Ag116": 115.911386809,
    "Cd116": 115.90476323,
    "In116": 115.905259992,
    "Sn116": 115.901742825,
    "Sb116": 115.906792732,
    "Te116": 115.908465558,
    "I116": 115.916885513,
    "Xe116": 115.921580955,
    "Cs116": 115.933395,
    "Ba116": 115.941621,
    "La116": 115.957005,
    "Mo117": 116.961686,
    "Tc117": 116.94832,
    "Ru117": 116.936135,
    "Rh117": 116.926036291,
    "Pd117": 116.917955584,
    "Ag117": 116.911774086,
    "Cd117": 116.907226039,
    "In117": 116.904515729,
    "Sn117": 116.902954036,
    "Sb117": 116.904841519,
    "Te117": 116.908646227,
    "I117": 116.913645649,
    "Xe117": 116.920358758,
    "Cs117": 116.928616723,
    "Ba117": 116.938316403,
    "La117": 116.950326,
    "Mo118": 117.965249,
    "Tc118": 117.953526,
    "Ru118": 117.938808,
    "Rh118": 117.930341116,
    "Pd118": 117.919067273,
    "Ag118": 117.914595484,
    "Cd118": 117.906921956,
    "In118": 117.906356705,
    "Sn118": 117.90160663,
    "Sb118": 117.905532194,
    "Te118": 117.905860104,
    "I118": 117.913074,
    "Xe118": 117.916178678,
    "Cs118": 117.926559517,
    "Ba118": 117.933226,
    "La118": 117.946731,
    "Mo119": 118.971465,
    "Tc119": 118.956876,
    "Ru119": 118.94409,
    "Rh119": 118.932556951,
    "Pd119": 118.923341138,
    "Ag119": 118.915570309,
    "Cd119": 118.909847052,
    "In119": 118.905851622,
    "Sn119": 118.903311266,
    "Sb119": 118.903944062,
    "Te119": 118.906405699,
    "I119": 118.91006091,
    "Xe119": 118.915410641,
    "Cs119": 118.922377327,
    "Ba119": 118.930659683,
    "La119": 118.940934,
    "Ce119": 118.952957,
    "Tc120": 119.962426,
    "Ru120": 119.946623,
    "Rh120": 119.937069,
    "Pd120": 119.924551745,
    "Ag120": 119.918784765,
    "Cd120": 119.909868065,
    "In120": 119.907967489,
    "Sn120": 119.902202557,
    "Sb120": 119.905080308,
    "Te120": 119.904065779,
    "I120": 119.910093729,
    "Xe120": 119.911784267,
    "Cs120": 119.920677277,
    "Ba120": 119.926044997,
    "La120": 119.938196,
    "Ce120": 119.946613,
    "Tc121": 120.96614,
    "Ru121": 120.952098,
    "Rh121": 120.939613,
    "Pd121": 120.928950342,
    "Ag121": 120.920125279,
    "Cd121": 120.91296366,
    "In121": 120.907852778,
    "Sn121": 120.904243488,
    "Sb121": 120.903811353,
    "Te121": 120.904945065,
    "I121": 120.907411492,
    "Xe121": 120.911453012,
    "Cs121": 120.917227235,
    "Ba121": 120.924052286,
    "La121": 120.933236,
    "Ce121": 120.943435,
    "Pr121": 120.955393,
    "Tc122": 121.97176,
    "Ru122": 121.955147,
    "Rh122": 121.944305,
    "Pd122": 121.930631693,
    "Ag122": 121.923664446,
    "Cd122": 121.91345905,
    "In122": 121.910282458,
    "Sn122": 121.903445494,
    "Sb122": 121.905169335,
    "Te122": 121.903044708,
    "I122": 121.907590094,
    "Xe122": 121.908367655,
    "Cs122": 121.916108144,
    "Ba122": 121.919904,
    "La122": 121.93071,
    "Ce122": 121.93787,
    "Pr122": 121.951927,
    "Ru123": 122.960762,
    "Rh123": 122.947192,
    "Pd123": 122.935126,
    "Ag123": 122.92531506,
    "Cd123": 122.91689246,
    "In123": 122.910435252,
    "Sn123": 122.905727065,
    "Sb123": 122.904215292,
    "Te123": 122.904271022,
    "I123": 122.905589753,
    "Xe123": 122.908482235,
    "Cs123": 122.91299606,
    "Ba123": 122.91878106,
    "La123": 122.9263,
    "Ce123": 122.93528,
    "Pr123": 122.946076,
    "Ru124": 123.96394,
    "Rh124": 123.952002,
    "Pd124": 123.937305,
    "Ag124": 123.928899227,
    "Cd124": 123.917659772,
    "In124": 123.913184873,
    "Sn124": 123.905279619,
    "Sb124": 123.905937065,
    "Te124": 123.902818341,
    "I124": 123.906210297,
    "Xe124": 123.905885174,
    "Cs124": 123.912247366,
    "Ba124": 123.915093627,
    "La124": 123.924574275,
    "Ce124": 123.93031,
    "Pr124": 123.94294,
    "Nd124": 123.951873,
    "Ru125": 124.969544,
    "Rh125": 124.955094,
    "Pd125": 124.942072,
    "Ag125": 124.930735,
    "Cd125": 124.92125759,
    "In125": 124.913673841,
    "Sn125": 124.90778937,
    "Sb125": 124.905254264,
    "Te125": 124.904431178,
    "I125": 124.90463061,
    "Xe125": 124.90638764,
    "Cs125": 124.909725953,
    "Ba125": 124.91447184,
    "La125": 124.92081593099999,
    "Ce125": 124.92844,
    "Pr125": 124.937659,
    "Nd125": 124.948395,
    "Rh126": 125.960064,
    "Pd126": 125.944401,
    "Ag126": 125.934814,
    "Cd126": 125.92243029,
    "In126": 125.916468202,
    "Sn126": 125.907658958,
    "Sb126": 125.907253158,
    "Te126": 125.903312144,
    "I126": 125.905624205,
    "Xe126": 125.904297422,
    "Cs126": 125.909445821,
    "Ba126": 125.911250202,
    "La126": 125.919512667,
    "Ce126": 125.923971,
    "Pr126": 125.93524,
    "Nd126": 125.942694,
    "Pm126": 125.957327,
    "Rh127": 126.963789,
    "Pd127": 126.949307,
    "Ag127": 126.937037,
    "Cd127": 126.926203291,
    "In127": 126.91746604,
    "Sn127": 126.910391726,
    "Sb127": 126.906925557,
    "Te127": 126.905226993,
    "I127": 126.904472592,
    "Xe127": 126.905183636,
    "Cs127": 126.907417527,
    "Ba127": 126.911091272,
    "La127": 126.916375083,
    "Ce127": 126.922727,
    "Pr127": 126.93071,
    "Nd127": 126.939978,
    "Pm127": 126.951358,
    "Rh128": 127.970649,
    "Pd128": 127.952345,
    "Ag128": 127.941266,
    "Cd128": 127.927816778,
    "In128": 127.920353637,
    "Sn128": 127.910507828,
    "Sb128": 127.909146121,
    "Te128": 127.904461237,
    "I128": 127.905809355,
    "Xe128": 127.90353075341,
    "Cs128": 127.907748452,
    "Ba128": 127.908352446,
    "La128": 127.915592123,
    "Ce128": 127.918911,
    "Pr128": 127.928791,
    "Nd128": 127.935018,
    "Pm128": 127.948234,
    "Sm128": 127.957971,
    "Pd129": 128.959334,
    "Ag129": 128.944315,
    "Cd129": 128.932235597,
    "In129": 128.921808534,
    "Sn129": 128.91348244,
    "Sb129": 128.909146623,
    "Te129": 128.906596419,
    "I129": 128.904983643,
    "Xe129": 128.90478085742,
    "Cs129": 128.90606591,
    "Ba129": 128.908683409,
    "La129": 128.912695592,
    "Ce129": 128.918102,
    "Pr129": 128.925095,
    "Nd129": 128.933038,
    "Pm129": 128.942909,
    "Sm129": 128.954557,
    "Pd130": 129.964863,
    "Ag130": 129.950727,
    "Cd130": 129.934387563,
    "In130": 129.924952257,
    "Sn130": 129.913974531,
    "Sb130": 129.911662686,
    "Te130": 129.906222745,
    "I130": 129.906670168,
    "Xe130": 129.903509346,
    "Cs130": 129.906709281,
    "Ba130": 129.906326002,
    "La130": 129.912369413,
    "Ce130": 129.914736,
    "Pr130": 129.92359,
    "Nd130": 129.928506,
    "Pm130": 129.940451,
    "Sm130": 129.948792,
    "Eu130": 129.964022,
    "Pd131": 130.972367,
    "Ag131": 130.956253,
    "Cd131": 130.94072774,
    "In131": 130.926972839,
    "Sn131": 130.917053067,
    "Sb131": 130.911989339,
    "Te131": 130.90852221,
    "I131": 130.906126375,
    "Xe131": 130.90508412808,
    "Cs131": 130.905468457,
    "Ba131": 130.906946315,
    "La131": 130.91007,
    "Ce131": 130.914429465,
    "Pr131": 130.92023496,
    "Nd131": 130.92724802,
    "Pm131": 130.935834,
    "Sm131": 130.946022,
    "Eu131": 130.957634,
    "Ag132": 131.96307,
    "Cd132": 131.945823136,
    "In132": 131.932998444,
    "Sn132": 131.917823898,
    "Sb132": 131.914508013,
    "Te132": 131.908546713,
    "I132": 131.907993511,
    "Xe132": 131.90415508346,
    "Cs132": 131.90643774,
    "Ba132": 131.905061231,
    "La132": 131.910119047,
    "Ce132": 131.911466226,
    "Pr132": 131.91924,
    "Nd132": 131.923321237,
    "Pm132": 131.93384,
    "Sm132": 131.940805,
    "Eu132": 131.954696,
    "Ag133": 132.968781,
    "Cd133": 132.952614,
    "In133": 132.938067,
    "Sn133": 132.923913753,
    "Sb133": 132.915272128,
    "Te133": 132.91096333,
    "I133": 132.9078284,
    "Xe133": 132.905910748,
    "Cs133": 132.905451958,
    "Ba133": 132.906007443,
    "La133": 132.908218,
    "Ce133": 132.911520402,
    "Pr133": 132.916330558,
    "Nd133": 132.922348,
    "Pm133": 132.929782,
    "Sm133": 132.93856,
    "Eu133": 132.94929,
    "Gd133": 132.961288,
    "Cd134": 133.957638,
    "In134": 133.944208,
    "Sn134": 133.92868043,
    "Sb134": 133.920537334,
    "Te134": 133.911396376,
    "I134": 133.90977566,
    "Xe134": 133.90539303,
    "Cs134": 133.906718501,
    "Ba134": 133.904508249,
    "La134": 133.908514011,
    "Ce134": 133.908928142,
    "Pr134": 133.915696729,
    "Nd134": 133.918790207,
    "Pm134": 133.928326,
    "Sm134": 133.93411,
    "Eu134": 133.946537,
    "Gd134": 133.955416,
    "Cd135": 134.964766,
    "In135": 134.949425,
    "Sn135": 134.934908603,
    "Sb135": 134.925184354,
    "Te135": 134.916554715,
    "I135": 134.910059355,
    "Xe135": 134.907231441,
    "Cs135": 134.905976907,
    "Ba135": 134.905688447,
    "La135": 134.906984427,
    "Ce135": 134.909160662,
    "Pr135": 134.913111772,
    "Nd135": 134.918181318,
    "Pm135": 134.92478499999999,
    "Sm135": 134.93252,
    "Eu135": 134.94187,
    "Gd135": 134.952496,
    "Tb135": 134.964516,
    "In136": 135.956017,
    "Sn136": 135.939699,
    "Sb136": 135.930749009,
    "Te136": 135.92010118,
    "I136": 135.914604693,
    "Xe136": 135.907214474,
    "Cs136": 135.907311431,
    "Ba136": 135.9045758,
    "La136": 135.907634962,
    "Ce136": 135.907129256,
    "Pr136": 135.91267747,
    "Nd136": 135.914976061,
    "Pm136": 135.923595949,
    "Sm136": 135.928275553,
    "Eu136": 135.93962,
    "Gd136": 135.9473,
    "Tb136": 135.96146,
    "In137": 136.961535,
    "Sn137": 136.946162,
    "Sb137": 136.935522519,
    "Te137": 136.925599354,
    "I137": 136.918028178,
    "Xe137": 136.911557771,
    "Cs137": 136.907089296,
    "Ba137": 136.905827207,
    "La137": 136.906450438,
    "Ce137": 136.907762416,
    "Pr137": 136.910679183,
    "Nd137": 136.914563099,
    "Pm137": 136.920479519,
    "Sm137": 136.927007959,
    "Eu137": 136.935430719,
    "Gd137": 136.94502,
    "Tb137": 136.95602,
    "Sn138": 137.951143,
    "Sb138": 137.941331,
    "Te138": 137.929472452,
    "I138": 137.922726392,
    "Xe138": 137.914146268,
    "Cs138": 137.911017119,
    "Ba138": 137.905247059,
    "La138": 137.907124041,
    "Ce138": 137.90599418,
    "Pr138": 137.910757495,
    "Nd138": 137.911950938,
    "Pm138": 137.919576119,
    "Sm138": 137.923243988,
    "Eu138": 137.933709,
    "Gd138": 137.940247,
    "Tb138": 137.953193,
    "Dy138": 137.9625,
    "Sn139": 138.957799,
    "Sb139": 138.946269,
    "Te139": 138.935367191,
    "I139": 138.9264934,
    "Xe139": 138.9187922,
    "Cs139": 138.913363822,
    "Ba139": 138.908841164,
    "La139": 138.906362927,
    "Ce139": 138.906647029,
    "Pr139": 138.9089327,
    "Nd139": 138.911951208,
    "Pm139": 138.916799228,
    "Sm139": 138.922296631,
    "Eu139": 138.929792307,
    "Gd139": 138.93813,
    "Tb139": 138.94833,
    "Dy139": 138.959527,
    "Sn140": 139.962973,
    "Sb140": 139.952345,
    "Te140": 139.939487057,
    "I140": 139.931715914,
    "Xe140": 139.921645814,
    "Cs140": 139.917283707,
    "Ba140": 139.910608231,
    "La140": 139.909487285,
    "Ce140": 139.905448433,
    "Pr140": 139.9090856,
    "Nd140": 139.90954613,
    "Pm140": 139.916035918,
    "Sm140": 139.918994714,
    "Eu140": 139.928087633,
    "Gd140": 139.933674,
    "Tb140": 139.945805048,
    "Dy140": 139.95402,
    "Ho140": 139.968526,
    "Sb141": 140.957552,
    "Te141": 140.945604,
    "I141": 140.935666081,
    "Xe141": 140.926787181,
    "Cs141": 140.920045279,
    "Ba141": 140.914403653,
    "La141": 140.910971155,
    "Ce141": 140.908285991,
    "Pr141": 140.907659604,
    "Nd141": 140.90961669,
    "Pm141": 140.913555081,
    "Sm141": 140.918481545,
    "Eu141": 140.924931734,
    "Gd141": 140.932126,
    "Tb141": 140.941448,
    "Dy141": 140.95128,
    "Ho141": 140.963108,
    "Sb142": 141.963918,
    "Te142": 141.950027,
    "I142": 141.941166595,
    "Xe142": 141.929973095,
    "Cs142": 141.924299514,
    "Ba142": 141.916432904,
    "La142": 141.91409076,
    "Ce142": 141.909250208,
    "Pr142": 141.91005164,
    "Nd142": 141.907728824,
    "Pm142": 141.912890982,
    "Sm142": 141.915209415,
    "Eu142": 141.923446719,
    "Gd142": 141.928116,
    "Tb142": 141.939280858,
    "Dy142": 141.946194,
    "Ho142": 141.96001,
    "Er142": 141.970016,
    "Te143": 142.956489,
    "I143": 142.945475,
    "Xe143": 142.93536955,
    "Cs143": 142.927347346,
    "Ba143": 142.920625149,
    "La143": 142.916079482,
    "Ce143": 142.912391953,
    "Pr143": 142.910822624,
    "Nd143": 142.909819815,
    "Pm143": 142.910938068,
    "Sm143": 142.914634848,
    "Eu143": 142.920298678,
    "Gd143": 142.926750678,
    "Tb143": 142.935137332,
    "Dy143": 142.943994332,
    "Ho143": 142.95486,
    "Er143": 142.966548,
    "Te144": 143.961116,
    "I144": 143.951336,
    "Xe144": 143.938945076,
    "Cs144": 143.932075402,
    "Ba144": 143.922954821,
    "La144": 143.919645589,
    "Ce144": 143.913652763,
    "Pr144": 143.913310682,
    "Nd144": 143.910092798,
    "Pm144": 143.912596208,
    "Sm144": 143.912006285,
    "Eu144": 143.918819481,
    "Gd144": 143.922963,
    "Tb144": 143.933045,
    "Dy144": 143.939269512,
    "Ho144": 143.952109712,
    "Er144": 143.9607,
    "Tm144": 143.976211,
    "Te145": 144.967783,
    "I145": 144.955845,
    "Xe145": 144.944719631,
    "Cs145": 144.935528927,
    "Ba145": 144.9275184,
    "La145": 144.921808065,
    "Ce145": 144.917265113,
    "Pr145": 144.914517987,
    "Nd145": 144.912579151,
    "Pm145": 144.912755748,
    "Sm145": 144.913417157,
    "Eu145": 144.916272659,
    "Gd145": 144.921710051,
    "Tb145": 144.928717001,
    "Dy145": 144.937473992,
    "Ho145": 144.947267392,
    "Er145": 144.957874,
    "Tm145": 144.970389,
    "I146": 145.961846,
    "Xe146": 145.948518245,
    "Cs146": 145.940621867,
    "Ba146": 145.9303632,
    "La146": 145.925688017,
    "Ce146": 145.918812294,
    "Pr146": 145.91768763,
    "Nd146": 145.913122459,
    "Pm146": 145.91470224,
    "Sm146": 145.913046835,
    "Eu146": 145.917210852,
    "Gd146": 145.918318513,
    "Tb146": 145.927252739,
    "Dy146": 145.932844526,
    "Ho146": 145.944993503,
    "Er146": 145.952418357,
    "Tm146": 145.966661,
    "I147": 146.966505,
    "Xe147": 146.954482,
    "Cs147": 146.944261512,
    "Ba147": 146.9353039,
    "La147": 146.9284178,
    "Ce147": 146.9226899,
    "Pr147": 146.919007438,
    "Nd147": 146.916105969,
    "Pm147": 146.915144944,
    "Sm147": 146.914904401,
    "Eu147": 146.91675244,
    "Gd147": 146.919101014,
    "Tb147": 146.92405462,
    "Dy147": 146.931082712,
    "Ho147": 146.940142293,
    "Er147": 146.949964456,
    "Tm147": 146.961379887,
    "Xe148": 147.958508,
    "Cs148": 147.949639026,
    "Ba148": 147.938223,
    "La148": 147.9326794,
    "Ce148": 147.924424186,
    "Pr148": 147.922129992,
    "Nd148": 147.916899027,
    "Pm148": 147.917481091,
    "Sm148": 147.914829233,
    "Eu148": 147.918091288,
    "Gd148": 147.918121414,
    "Tb148": 147.924275476,
    "Dy148": 147.927149944,
    "Ho148": 147.937743925,
    "Er148": 147.944735026,
    "Tm148": 147.958384026,
    "Yb148": 147.967547,
    "Xe149": 148.964573,
    "Cs149": 148.953516,
    "Ba149": 148.943284,
    "La149": 148.935351259,
    "Ce149": 148.9284269,
    "Pr149": 148.9237361,
    "Nd149": 148.920154583,
    "Pm149": 148.918341507,
    "Sm149": 148.917191211,
    "Eu149": 148.917936875,
    "Gd149": 148.919347666,
    "Tb149": 148.923253792,
    "Dy149": 148.927327516,
    "Ho149": 148.933820457,
    "Er149": 148.942306,
    "Tm149": 148.952828,
    "Yb149": 148.964219,
    "Xe150": 149.968878,
    "Cs150": 149.959023,
    "Ba150": 149.9464411,
    "La150": 149.9395475,
    "Ce150": 149.930384032,
    "Pr150": 149.926676391,
    "Nd150": 149.920901322,
    "Pm150": 149.920990014,
    "Sm150": 149.917281993,
    "Eu150": 149.919707092,
    "Gd150": 149.918663949,
    "Tb150": 149.923664799,
    "Dy150": 149.925593068,
    "Ho150": 149.933498353,
    "Er150": 149.937915524,
    "Tm150": 149.95009,
    "Yb150": 149.958314,
    "Lu150": 149.973407,
    "Cs151": 150.963199,
    "Ba151": 150.951755,
    "La151": 150.942769,
    "Ce151": 150.9342722,
    "Pr151": 150.928309066,
    "Nd151": 150.923839363,
    "Pm151": 150.921216613,
    "Sm151": 150.919938859,
    "Eu151": 150.919856606,
    "Gd151": 150.920354922,
    "Tb151": 150.92310897,
    "Dy151": 150.926191279,
    "Ho151": 150.931698176,
    "Er151": 150.937448567,
    "Tm151": 150.945494433,
    "Yb151": 150.955402453,
    "Lu151": 150.967471,
    "Cs152": 151.968728,
    "Ba152": 151.95533,
    "La152": 151.947085,
    "Ce152": 151.936682,
    "Pr152": 151.9315529,
    "Nd152": 151.924691242,
    "Pm152": 151.923505185,
    "Sm152": 151.919738646,
    "Eu152": 151.92175098,
    "Gd152": 151.919798414,
    "Tb152": 151.924081855,
    "Dy152": 151.924725274,
    "Ho152": 151.931717618,
    "Er152": 151.935050347,
    "Tm152": 151.944476,
    "Yb152": 151.950326699,
    "Lu152": 151.96412,
    "Ba153": 152.960848,
    "La153": 152.950553,
    "Ce153": 152.941052,
    "Pr153": 152.933903511,
    "Nd153": 152.927717868,
    "Pm153": 152.924156252,
    "Sm153": 152.922103576,
    "Eu153": 152.921236789,
    "Gd153": 152.921756945,
    "Tb153": 152.923441694,
    "Dy153": 152.925771729,
    "Ho153": 152.930206671,
    "Er153": 152.93508635,
    "Tm153": 152.942058023,
    "Yb153": 152.949372,
    "Lu153": 152.958802248,
    "Hf153": 152.970692,
    "Ba154": 153.964659,
    "La154": 153.955416,
    "Ce154": 153.94394,
    "Pr154": 153.937885165,
    "Nd154": 153.929597404,
    "Pm154": 153.926712791,
    "Sm154": 153.922215756,
    "Eu154": 153.922985699,
    "Gd154": 153.920872974,
    "Tb154": 153.924683681,
    "Dy154": 153.92442892,
    "Ho154": 153.930606776,
    "Er154": 153.932790799,
    "Tm154": 153.941570062,
    "Yb154": 153.946395696,
    "Lu154": 153.957416,
    "Hf154": 153.964863,
    "La155": 154.95928,
    "Ce155": 154.948706,
    "Pr155": 154.940509193,
    "Nd155": 154.933135598,
    "Pm155": 154.928136951,
    "Sm155": 154.924646645,
    "Eu155": 154.922899847,
    "Gd155": 154.922629356,
    "Tb155": 154.923509511,
    "Dy155": 154.925758049,
    "Ho155": 154.929103363,
    "Er155": 154.93321571,
    "Tm155": 154.939209576,
    "Yb155": 154.945783216,
    "Lu155": 154.954326005,
    "Hf155": 154.963167,
    "Ta155": 154.974248,
    "La156": 155.964519,
    "Ce156": 155.951884,
    "Pr156": 155.9447669,
    "Nd156": 155.935370358,
    "Pm156": 155.931114059,
    "Sm156": 155.925538191,
    "Eu156": 155.924762976,
    "Gd156": 155.92213012,
    "Tb156": 155.924754209,
    "Dy156": 155.924283593,
    "Ho156": 155.929641634,
    "Er156": 155.931065926,
    "Tm156": 155.938985746,
    "Yb156": 155.942817096,
    "Lu156": 155.953086606,
    "Hf156": 155.959399083,
    "Ta156": 155.972087,
    "La157": 156.968792,
    "Ce157": 156.957133,
    "Pr157": 156.9480031,
    "Nd157": 156.939351074,
    "Pm157": 156.933121298,
    "Sm157": 156.928418598,
    "Eu157": 156.925432556,
    "Gd157": 156.923967424,
    "Tb157": 156.924031888,
    "Dy157": 156.925469555,
    "Ho157": 156.928251974,
    "Er157": 156.931922652,
    "Tm157": 156.936973,
    "Yb157": 156.94265136799999,
    "Lu157": 156.950144807,
    "Hf157": 156.958288,
    "Ta157": 156.968227445,
    "W157": 156.978862,
    "Ce158": 157.960773,
    "Pr158": 157.952603,
    "Nd158": 157.94220562,
    "Pm158": 157.936546948,
    "Sm158": 157.929949262,
    "Eu158": 157.927782192,
    "Gd158": 157.9241112,
    "Tb158": 157.925419942,
    "Dy158": 157.924414817,
    "Ho158": 157.92894491,
    "Er158": 157.929893474,
    "Tm158": 157.936979525,
    "Yb158": 157.939871202,
    "Lu158": 157.94931562,
    "Hf158": 157.954801217,
    "Ta158": 157.966593,
    "W158": 157.974565,
    "Ce159": 158.966355,
    "Pr159": 158.956232,
    "Nd159": 158.946619085,
    "Pm159": 158.939286409,
    "Sm159": 158.93321713,
    "Eu159": 158.929099512,
    "Gd159": 158.926395822,
    "Tb159": 158.925353707,
    "Dy159": 158.925745938,
    "Ho159": 158.927718683,
    "Er159": 158.93069079,
    "Tm159": 158.934975,
    "Yb159": 158.940060257,
    "Lu159": 158.946635615,
    "Hf159": 158.953995837,
    "Ta159": 158.963028046,
    "W159": 158.972696,
    "Re159": 158.984106,
    "Pr160": 159.961138,
    "Nd160": 159.949839172,
    "Pm160": 159.943215272,
    "Sm160": 159.935337032,
    "Eu160": 159.931836982,
    "Gd160": 159.927061202,
    "Tb160": 159.927174553,
    "Dy160": 159.925203578,
    "Ho160": 159.928735538,
    "Er160": 159.929077193,
    "Tm160": 159.935264177,
    "Yb160": 159.93755921,
    "Lu160": 159.946033,
    "Hf160": 159.950682728,
    "Ta160": 159.961541678,
    "W160": 159.968513946,
    "Re160": 159.98188,
    "Pr161": 160.965121,
    "Nd161": 160.954664,
    "Pm161": 160.946229837,
    "Sm161": 160.939160062,
    "Eu161": 160.933663991,
    "Gd161": 160.929676267,
    "Tb161": 160.927576806,
    "Dy161": 160.926939425,
    "Ho161": 160.927861815,
    "Er161": 160.93000353,
    "Tm161": 160.933549,
    "Yb161": 160.937912384,
    "Lu161": 160.943572,
    "Hf161": 160.950277927,
    "Ta161": 160.958369489,
    "W161": 160.967249,
    "Re161": 160.977624313,
    "Os161": 160.989054,
    "Nd162": 161.958121,
    "Pm162": 161.950574,
    "Sm162": 161.941621687,
    "Eu162": 161.936958329,
    "Gd162": 161.930991812,
    "Tb162": 161.9292754,
    "Dy162": 161.92680450699999,
    "Ho162": 161.929102543,
    "Er162": 161.928787299,
    "Tm162": 161.934001211,
    "Yb162": 161.935779342,
    "Lu162": 161.943282776,
    "Hf162": 161.947215526,
    "Ta162": 161.957292907,
    "W162": 161.963500341,
    "Re162": 161.975896,
    "Os162": 161.984434,
    "Nd163": 162.963414,
    "Pm163": 162.953881,
    "Sm163": 162.945679085,
    "Eu163": 162.93926551,
    "Gd163": 162.93409664,
    "Tb163": 162.930653609,
    "Dy163": 162.928737221,
    "Ho163": 162.92874026,
    "Er163": 162.930039908,
    "Tm163": 162.932658282,
    "Yb163": 162.936345406,
    "Lu163": 162.941179,
    "Hf163": 162.947107211,
    "Ta163": 162.954337194,
    "W163": 162.962524251,
    "Re163": 162.972085434,
    "Os163": 162.982462,
    "Ir163": 162.994299,
    "Pm164": 163.958819,
    "Sm164": 163.948550061,
    "Eu164": 163.942852943,
    "Gd164": 163.935916193,
    "Tb164": 163.933327561,
    "Dy164": 163.929180819,
    "Ho164": 163.930240548,
    "Er164": 163.929207739,
    "Tm164": 163.933538019,
    "Yb164": 163.934500743,
    "Lu164": 163.941339,
    "Hf164": 163.944370709,
    "Ta164": 163.953534,
    "W164": 163.958952445,
    "Re164": 163.970507122,
    "Os164": 163.978073158,
    "Ir164": 163.991966,
    "Pm165": 164.96278,
    "Sm165": 164.95329,
    "Eu165": 164.94554007,
    "Gd165": 164.93931708,
    "Tb165": 164.934955198,
    "Dy165": 164.931709402,
    "Ho165": 164.930329116,
    "Er165": 164.930733482,
    "Tm165": 164.932441843,
    "Yb165": 164.935270241,
    "Lu165": 164.939406758,
    "Hf165": 164.944567,
    "Ta165": 164.950780287,
    "W165": 164.958280663,
    "Re165": 164.967085831,
    "Os165": 164.976654,
    "Ir165": 164.987552,
    "Pt165": 164.999658,
    "Sm166": 165.956575,
    "Eu166": 165.949813,
    "Gd166": 165.941630413,
    "Tb166": 165.937939727,
    "Dy166": 165.93281281,
    "Ho166": 165.932291209,
    "Er166": 165.930301067,
    "Tm166": 165.933562136,
    "Yb166": 165.933876439,
    "Lu166": 165.939859,
    "Hf166": 165.94218,
    "Ta166": 165.950512,
    "W166": 165.955031952,
    "Re166": 165.965821216,
    "Os166": 165.972698135,
    "Ir166": 165.985716,
    "Pt166": 165.994866,
    "Sm167": 166.962072,
    "Eu167": 166.953011,
    "Gd167": 166.945490012,
    "Tb167": 166.940007046,
    "Dy167": 166.935682415,
    "Ho167": 166.933140254,
    "Er167": 166.932056192,
    "Tm167": 166.932857206,
    "Yb167": 166.934954069,
    "Lu167": 166.938243,
    "Hf167": 166.9426,
    "Ta167": 166.948093,
    "W167": 166.95481108,
    "Re167": 166.962604,
    "Os167": 166.971552304,
    "Ir167": 166.981671973,
    "Pt167": 166.99275,
    "Sm168": 167.966033,
    "Eu168": 167.957863,
    "Gd168": 167.948309,
    "Tb168": 167.943337074,
    "Dy168": 167.937134977,
    "Ho168": 167.935523766,
    "Er168": 167.932378282,
    "Tm168": 167.934178457,
    "Yb168": 167.933891297,
    "Lu168": 167.938729798,
    "Hf168": 167.940568,
    "Ta168": 167.948047,
    "W168": 167.951805459,
    "Re168": 167.961572607,
    "Os168": 167.96779905,
    "Ir168": 167.979960978,
    "Pt168": 167.988180196,
    "Au168": 168.002716,
    "Eu169": 168.961717,
    "Gd169": 168.952882,
    "Tb169": 168.945807,
    "Dy169": 168.940315231,
    "Ho169": 168.93687989,
    "Er169": 168.934598444,
    "Tm169": 168.934218956,
    "Yb169": 168.935184208,
    "Lu169": 168.937645845,
    "Hf169": 168.941259,
    "Ta169": 168.946011,
    "W169": 168.951778689,
    "Re169": 168.958765979,
    "Os169": 168.967017521,
    "Ir169": 168.976281743,
    "Pt169": 168.986619,
    "Au169": 168.99808,
    "Eu170": 169.96687,
    "Gd170": 169.956146,
    "Tb170": 169.949855,
    "Dy170": 169.94234,
    "Ho170": 169.939626548,
    "Er170": 169.935471933,
    "Tm170": 169.935807093,
    "Yb170": 169.934767242,
    "Lu170": 169.93847923,
    "Hf170": 169.939609,
    "Ta170": 169.946175,
    "W170": 169.949231235,
    "Re170": 169.958234844,
    "Os170": 169.963579273,
    "Ir170": 169.975113,
    "Pt170": 169.982502087,
    "Au170": 169.996024,
    "Hg170": 170.005814,
    "Gd171": 170.961127,
    "Tb171": 170.953011,
    "Dy171": 170.946312,
    "Ho171": 170.941472713,
    "Er171": 170.938037372,
    "Tm171": 170.936435162,
    "Yb171": 170.936331515,
    "Lu171": 170.937918591,
    "Hf171": 170.940492,
    "Ta171": 170.944476,
    "W171": 170.949451,
    "Re171": 170.955716,
    "Os171": 170.963180402,
    "Ir171": 170.97164552,
    "Pt171": 170.981248868,
    "Au171": 170.991881533,
    "Hg171": 171.003585,
    "Gd172": 171.964605,
    "Tb172": 171.957391,
    "Dy172": 171.948728,
    "Ho172": 171.94473,
    "Er172": 171.939363461,
    "Tm172": 171.938406959,
    "Yb172": 171.936386654,
    "Lu172": 171.93909132,
    "Hf172": 171.939449716,
    "Ta172": 171.944895,
    "W172": 171.947292,
    "Re172": 171.955376165,
    "Os172": 171.960017309,
    "Ir172": 171.970607035,
    "Pt172": 171.977341059,
    "Au172": 171.989996704,
    "Hg172": 171.998860581,
    "Tb173": 172.960805,
    "Dy173": 172.953043,
    "Ho173": 172.94702,
    "Er173": 172.9424,
    "Tm173": 172.93960663,
    "Yb173": 172.938216211,
    "Lu173": 172.938935722,
    "Hf173": 172.940513,
    "Ta173": 172.94375,
    "W173": 172.947689,
    "Re173": 172.953243,
    "Os173": 172.959808387,
    "Ir173": 172.967505477,
    "Pt173": 172.976449922,
    "Au173": 172.986224263,
    "Hg173": 172.997143,
    "Tb174": 173.965679,
    "Dy174": 173.955845,
    "Ho174": 173.950757,
    "Er174": 173.94423,
    "Tm174": 173.942174061,
    "Yb174": 173.938867545,
    "Lu174": 173.94034284,
    "Hf174": 173.940048377,
    "Ta174": 173.944454,
    "W174": 173.946079,
    "Re174": 173.953115,
    "Os174": 173.957063192,
    "Ir174": 173.966949939,
    "Pt174": 173.972820431,
    "Au174": 173.984908,
    "Hg174": 173.992870575,
    "Dy175": 174.960569,
    "Ho175": 174.953516,
    "Er175": 174.94777,
    "Tm175": 174.94384231,
    "Yb175": 174.941281907,
    "Lu175": 174.940777211,
    "Hf175": 174.941511424,
    "Ta175": 174.943737,
    "W175": 174.946717,
    "Re175": 174.951381,
    "Os175": 174.956945126,
    "Ir175": 174.964149519,
    "Pt175": 174.972400593,
    "Au175": 174.981316375,
    "Hg175": 174.991444451,
    "Dy176": 175.963918,
    "Ho176": 175.957713,
    "Er176": 175.94994,
    "Tm176": 175.946997707,
    "Yb176": 175.942574706,
    "Lu176": 175.942691711,
    "Hf176": 175.941409797,
    "Ta176": 175.944857,
    "W176": 175.945634,
    "Re176": 175.951623,
    "Os176": 175.954770315,
    "Ir176": 175.963626261,
    "Pt176": 175.968938162,
    "Au176": 175.980116925,
    "Hg176": 175.98734867,
    "Tl176": 176.000627731,
    "Ho177": 176.961052,
    "Er177": 176.95399,
    "Tm177": 176.948932,
    "Yb177": 176.945263846,
    "Lu177": 176.94376357,
    "Hf177": 176.943230187,
    "Ta177": 176.94448194,
    "W177": 176.946643,
    "Re177": 176.950328,
    "Os177": 176.954957902,
    "Ir177": 176.9613015,
    "Pt177": 176.968469541,
    "Au177": 176.976869701,
    "Hg177": 176.98628459,
    "Tl177": 176.996414252,
    "Ho178": 177.965507,
    "Er178": 177.956779,
    "Tm178": 177.952506,
    "Yb178": 177.9466694,
    "Lu178": 177.945960065,
    "Hf178": 177.943708322,
    "Ta178": 177.94568,
    "W178": 177.945885791,
    "Re178": 177.950989,
    "Os178": 177.953253334,
    "Ir178": 177.961079395,
    "Pt178": 177.965649288,
    "Au178": 177.976056714,
    "Hg178": 177.982484756,
    "Tl178": 177.995047,
    "Pb178": 178.003836171,
    "Er179": 178.961267,
    "Tm179": 178.955018,
    "Yb179": 178.94993,
    "Lu179": 178.947332985,
    "Hf179": 178.945825705,
    "Ta179": 178.94593905,
    "W179": 178.947079378,
    "Re179": 178.949989686,
    "Os179": 178.953815985,
    "Ir179": 178.959117594,
    "Pt179": 178.965358742,
    "Au179": 178.973173666,
    "Hg179": 178.981821759,
    "Tl179": 178.991122185,
    "Pb179": 179.002202492,
    "Er180": 179.96438,
    "Tm180": 179.959023,
    "Yb180": 179.951991,
    "Lu180": 179.949890744,
    "Hf180": 179.946559537,
    "Ta180": 179.947467589,
    "W180": 179.946713304,
    "Re180": 179.950791568,
    "Os180": 179.952381665,
    "Ir180": 179.959229446,
    "Pt180": 179.96303801,
    "Au180": 179.972489738,
    "Hg180": 179.97826018,
    "Tl180": 179.98991895,
    "Pb180": 179.997916177,
    "Tm181": 180.961954,
    "Yb181": 180.95589,
    "Lu181": 180.951908,
    "Hf181": 180.949110834,
    "Ta181": 180.947998528,
    "W181": 180.948218733,
    "Re181": 180.950061507,
    "Os181": 180.953247188,
    "Ir181": 180.957634691,
    "Pt181": 180.963089946,
    "Au181": 180.970079102,
    "Hg181": 180.977819368,
    "Tl181": 180.986259978,
    "Pb181": 180.9966606,
    "Tm182": 181.966194,
    "Yb182": 181.958239,
    "Lu182": 181.955158,
    "Hf182": 181.950563684,
    "Ta182": 181.950154612,
    "W182": 181.948205636,
    "Re182": 181.95121156,
    "Os182": 181.952110154,
    "Ir182": 181.958076296,
    "Pt182": 181.961171605,
    "Au182": 181.969614433,
    "Hg182": 181.974689173,
    "Tl182": 181.985692649,
    "Pb182": 181.992673537,
    "Yb183": 182.962426,
    "Lu183": 182.957363,
    "Hf183": 182.953533203,
    "Ta183": 182.95137538,
    "W183": 182.950224416,
    "Re183": 182.950821306,
    "Os183": 182.953125028,
    "Ir183": 182.956841231,
    "Pt183": 182.961595895,
    "Au183": 182.967588106,
    "Hg183": 182.974444652,
    "Tl183": 182.982192843,
    "Pb183": 182.991862527,
    "Yb184": 183.965002,
    "Lu184": 183.96103,
    "Hf184": 183.955448507,
    "Ta184": 183.954009958,
    "W184": 183.95093318,
    "Re184": 183.952528073,
    "Os184": 183.952492919,
    "Ir184": 183.957476,
    "Pt184": 183.959921929,
    "Au184": 183.967451523,
    "Hg184": 183.971717709,
    "Tl184": 183.981874973,
    "Pb184": 183.988135634,
    "Bi184": 184.001347,
    "Yb185": 184.969425,
    "Lu185": 184.963542,
    "Hf185": 184.958862,
    "Ta185": 184.955561317,
    "W185": 184.953421206,
    "Re185": 184.95295832,
    "Os185": 184.954045969,
    "Ir185": 184.956698,
    "Pt185": 184.960613659,
    "Au185": 184.965798871,
    "Hg185": 184.971890696,
    "Tl185": 184.978789189,
    "Pb185": 184.98761,
    "Bi185": 184.9976,
    "Lu186": 185.96745,
    "Hf186": 185.960897,
    "Ta186": 185.958553036,
    "W186": 185.95436514,
    "Re186": 185.954989172,
    "Os186": 185.953837569,
    "Ir186": 185.957946754,
    "Pt186": 185.959350845,
    "Au186": 185.965952703,
    "Hg186": 185.969362061,
    "Tl186": 185.978654787,
    "Pb186": 185.984239409,
    "Bi186": 185.996623169,
    "Po186": 186.004403174,
    "Lu187": 186.970188,
    "Hf187": 186.964573,
    "Ta187": 186.960391,
    "W187": 186.957161249,
    "Re187": 186.955752217,
    "Os187": 186.955749569,
    "Ir187": 186.957542,
    "Pt187": 186.960616646,
    "Au187": 186.964542147,
    "Hg187": 186.96981354,
    "Tl187": 186.97590474,
    "Pb187": 186.983910842,
    "Bi187": 186.993147272,
    "Po187": 187.003031482,
    "Lu188": 187.974428,
    "Hf188": 187.966903,
    "Ta188": 187.963596,
    "W188": 187.958488325,
    "Re188": 187.958113658,
    "Os188": 187.955837292,
    "Ir188": 187.958834999,
    "Pt188": 187.959397521,
    "Au188": 187.965247966,
    "Hg188": 187.967580738,
    "Tl188": 187.976020886,
    "Pb188": 187.980879079,
    "Bi188": 187.992276064,
    "Po188": 187.999415586,
    "Hf189": 188.970853,
    "Ta189": 188.96569,
    "W189": 188.961557,
    "Re189": 188.959227764,
    "Os189": 188.958145949,
    "Ir189": 188.958722602,
    "Pt189": 188.960848485,
    "Au189": 188.963948286,
    "Hg189": 188.968194776,
    "Tl189": 188.973573525,
    "Pb189": 188.980843658,
    "Bi189": 188.989195139,
    "Po189": 188.998473425,
    "Hf190": 189.973376,
    "Ta190": 189.969168,
    "W190": 189.963103542,
    "Re190": 189.961800064,
    "Os190": 189.958445442,
    "Ir190": 189.960543374,
    "Pt190": 189.959949823,
    "Au190": 189.964751746,
    "Hg190": 189.96632225,
    "Tl190": 189.973841771,
    "Pb190": 189.978081872,
    "Bi190": 189.988624828,
    "Po190": 189.995101731,
    "Ta191": 190.97153,
    "W191": 190.966531,
    "Re191": 190.963123322,
    "Os191": 190.960928105,
    "Ir191": 190.960591455,
    "Pt191": 190.961676261,
    "Au191": 190.963716452,
    "Hg191": 190.967158301,
    "Tl191": 190.971784093,
    "Pb191": 190.978216455,
    "Bi191": 190.985786972,
    "Po191": 190.994558494,
    "At191": 191.004148081,
    "Ta192": 191.975201,
    "W192": 191.968202,
    "Re192": 191.966088,
    "Os192": 191.961478765,
    "Ir192": 191.962602414,
    "Pt192": 191.961042667,
    "Au192": 191.964817615,
    "Hg192": 191.965634263,
    "Tl192": 191.972225,
    "Pb192": 191.975789598,
    "Bi192": 191.985470077,
    "Po192": 191.991340274,
    "At192": 192.003140912,
    "Ta193": 192.97766,
    "W193": 192.971884,
    "Re193": 192.967545,
    "Os193": 192.964149637,
    "Ir193": 192.962923753,
    "Pt193": 192.962984546,
    "Au193": 192.964138442,
    "Hg193": 192.966653395,
    "Tl193": 192.970501994,
    "Pb193": 192.976135914,
    "Bi193": 192.98294722,
    "Po193": 192.991062421,
    "At193": 192.999927725,
    "Rn193": 193.009707973,
    "Ta194": 193.98161,
    "W194": 193.973795,
    "Re194": 193.970735,
    "Os194": 193.965179407,
    "Ir194": 193.965075703,
    "Pt194": 193.962683498,
    "Au194": 193.965419051,
    "Hg194": 193.965449108,
    "Tl194": 193.971081408,
    "Pb194": 193.974011788,
    "Bi194": 193.982798581,
    "Po194": 193.988186058,
    "At194": 193.999230816,
    "Rn194": 194.006145636,
    "W195": 194.977735,
    "Re195": 194.97256,
    "Os195": 194.968318,
    "Ir195": 194.965976898,
    "Pt195": 194.964794325,
    "Au195": 194.965037823,
    "Hg195": 194.966705809,
    "Tl195": 194.969774052,
    "Pb195": 194.974516167,
    "Bi195": 194.980648759,
    "Po195": 194.988065781,
    "At195": 194.99627448,
    "Rn195": 195.005421703,
    "W196": 195.979882,
    "Re196": 195.975996,
    "Os196": 195.969643261,
    "Ir196": 195.968399669,
    "Pt196": 195.964954648,
    "Au196": 195.966571213,
    "Hg196": 195.965833445,
    "Tl196": 195.970481189,
    "Pb196": 195.972787552,
    "Bi196": 195.980666509,
    "Po196": 195.985540722,
    "At196": 195.995799034,
    "Rn196": 196.002120431,
    "W197": 196.984036,
    "Re197": 196.978153,
    "Os197": 196.973076,
    "Ir197": 196.969657217,
    "Pt197": 196.96734303,
    "Au197": 196.966570103,
    "Hg197": 196.967213715,
    "Tl197": 196.969560492,
    "Pb197": 196.973434737,
    "Bi197": 196.978864927,
    "Po197": 196.985621939,
    "At197": 196.993177353,
    "Rn197": 197.001621446,
    "Fr197": 197.011008086,
    "Re198": 197.98176,
    "Os198": 197.974664,
    "Ir198": 197.972399,
    "Pt198": 197.967896718,
    "Au198": 197.968243714,
    "Hg198": 197.966769177,
    "Tl198": 197.970446669,
    "Pb198": 197.97201545,
    "Bi198": 197.979201316,
    "Po198": 197.983388753,
    "At198": 197.992797864,
    "Rn198": 197.998679197,
    "Fr198": 198.010282081,
    "Re199": 198.984187,
    "Os199": 198.978239,
    "Ir199": 198.973807097,
    "Pt199": 198.970597022,
    "Au199": 198.968766573,
    "Hg199": 198.968280994,
    "Tl199": 198.969877,
    "Pb199": 198.97291262,
    "Bi199": 198.977672841,
    "Po199": 198.983640445,
    "At199": 198.990527715,
    "Rn199": 198.998325436,
    "Fr199": 199.007269384,
    "Os200": 199.980086,
    "Ir200": 199.976844,
    "Pt200": 199.971444609,
    "Au200": 199.970756558,
    "Hg200": 199.968326941,
    "Tl200": 199.970963608,
    "Pb200": 199.971818546,
    "Bi200": 199.97813129,
    "Po200": 199.981812355,
    "At200": 199.990351099,
    "Rn200": 199.995705335,
    "Fr200": 200.006584666,
    "Os201": 200.984069,
    "Ir201": 200.978701,
    "Pt201": 200.974513305,
    "Au201": 200.971657678,
    "Hg201": 200.970303054,
    "Tl201": 200.970820235,
    "Pb201": 200.972870431,
    "Bi201": 200.976995017,
    "Po201": 200.982263799,
    "At201": 200.988417058,
    "Rn201": 200.995590511,
    "Fr201": 201.003852491,
    "Ra201": 201.012814699,
    "Os202": 201.986548,
    "Ir202": 201.982136,
    "Pt202": 201.975639,
    "Au202": 201.973856,
    "Hg202": 201.970643604,
    "Tl202": 201.972108874,
    "Pb202": 201.972151613,
    "Bi202": 201.977723042,
    "Po202": 201.980738934,
    "At202": 201.988625686,
    "Rn202": 201.993263982,
    "Fr202": 202.003329637,
    "Ra202": 202.009742305,
    "Os203": 202.992195,
    "Ir203": 202.984573,
    "Pt203": 202.979055,
    "Au203": 202.975154492,
    "Hg203": 202.972872396,
    "Tl203": 202.972344098,
    "Pb203": 202.973390617,
    "Bi203": 202.976892077,
    "Po203": 202.981416072,
    "At203": 202.986942904,
    "Rn203": 202.993361155,
    "Fr203": 203.000940867,
    "Ra203": 203.009233907,
    "Ir204": 203.989726,
    "Pt204": 203.981084,
    "Au204": 203.97811,
    "Hg204": 203.973494037,
    "Tl204": 203.97386342,
    "Pb204": 203.973043506,
    "Bi204": 203.977835687,
    "Po204": 203.980310078,
    "At204": 203.987251393,
    "Rn204": 203.991443729,
    "Fr204": 204.000651972,
    "Ra204": 204.006506855,
    "Ir205": 204.993988,
    "Pt205": 204.986237,
    "Au205": 204.980064,
    "Hg205": 204.976073151,
    "Tl205": 204.974427318,
    "Pb205": 204.974481682,
    "Bi205": 204.977385182,
    "Po205": 204.981190006,
    "At205": 204.986060546,
    "Rn205": 204.991723228,
    "Fr205": 204.998593854,
    "Ra205": 205.006230692,
    "Ac205": 205.015144152,
    "Pt206": 205.99008,
    "Au206": 205.984766,
    "Hg206": 205.977513837,
    "Tl206": 205.976110108,
    "Pb206": 205.97446521,
    "Bi206": 205.978498843,
    "Po206": 205.980473662,
    "At206": 205.986645768,
    "Rn206": 205.990195409,
    "Fr206": 205.998661441,
    "Ra206": 206.003827842,
    "Ac206": 206.014476477,
    "Pt207": 206.995556,
    "Au207": 206.988577,
    "Hg207": 206.9823,
    "Tl207": 206.977418605,
    "Pb207": 206.975896821,
    "Bi207": 206.978470551,
    "Po207": 206.981593334,
    "At207": 206.985799715,
    "Rn207": 206.990730224,
    "Fr207": 206.99694145,
    "Ra207": 207.00377242,
    "Ac207": 207.011965967,
    "Pt208": 207.999463,
    "Au208": 207.993655,
    "Hg208": 207.985759,
    "Tl208": 207.982018006,
    "Pb208": 207.976652005,
    "Bi208": 207.97974206,
    "Po208": 207.981246035,
    "At208": 207.986613011,
    "Rn208": 207.989634513,
    "Fr208": 207.997139082,
    "Ra208": 208.001855012,
    "Ac208": 208.011552251,
    "Th208": 208.017915348,
    "Au209": 208.997606,
    "Hg209": 208.990757,
    "Tl209": 208.985351713,
    "Pb209": 208.981089978,
    "Bi209": 208.980398599,
    "Po209": 208.982430361,
    "At209": 208.986168701,
    "Rn209": 208.990401389,
    "Fr209": 208.995939701,
    "Ra209": 209.001994902,
    "Ac209": 209.009495375,
    "Th209": 209.017601,
    "Au210": 210.002877,
    "Hg210": 209.99431,
    "Tl210": 209.990072942,
    "Pb210": 209.984188381,
    "Bi210": 209.984120237,
    "Po210": 209.982873686,
    "At210": 209.987147423,
    "Rn210": 209.989688862,
    "Fr210": 209.996410596,
    "Ra210": 210.000475406,
    "Ac210": 210.009408625,
    "Th210": 210.015093515,
    "Hg211": 210.999581,
    "Tl211": 210.993475,
    "Pb211": 210.988735288,
    "Bi211": 210.987268715,
    "Po211": 210.986653171,
    "At211": 210.987496226,
    "Rn211": 210.990600767,
    "Fr211": 210.995555189,
    "Ra211": 211.000893049,
    "Ac211": 211.007668846,
    "Th211": 211.014896923,
    "Pa211": 211.023674036,
    "Hg212": 212.003242,
    "Tl212": 211.998335,
    "Pb212": 211.991895891,
    "Bi212": 211.99128503,
    "Po212": 211.988867982,
    "At212": 211.990737301,
    "Rn212": 211.990703946,
    "Fr212": 211.99622542,
    "Ra212": 211.999786619,
    "Ac212": 212.007836442,
    "Th212": 212.01300157,
    "Pa212": 212.023184819,
    "Hg213": 213.008803,
    "Tl213": 213.001915,
    "Pb213": 212.996560796,
    "Bi213": 212.99438357,
    "Po213": 212.992857154,
    "At213": 212.992936593,
    "Rn213": 212.993885147,
    "Fr213": 212.99618441,
    "Ra213": 213.000370971,
    "Ac213": 213.006592665,
    "Th213": 213.01301147,
    "Pa213": 213.021099644,
    "Hg214": 214.012636,
    "Tl214": 214.00694,
    "Pb214": 213.999803521,
    "Bi214": 213.998710909,
    "Po214": 213.995201287,
    "At214": 213.996372331,
    "Rn214": 213.99536265,
    "Fr214": 213.998971193,
    "Ra214": 214.00009956,
    "Ac214": 214.0069064,
    "Th214": 214.01148148,
    "Pa214": 214.020891055,
    "Hg215": 215.018368,
    "Tl215": 215.010768,
    "Pb215": 215.004661591,
    "Bi215": 215.001749095,
    "Po215": 214.999418385,
    "At215": 214.998651002,
    "Rn215": 214.998745037,
    "Fr215": 215.000341534,
    "Ra215": 215.002718208,
    "Ac215": 215.006474061,
    "Th215": 215.01172464,
    "Pa215": 215.019113955,
    "U215": 215.026719774,
    "Hg216": 216.022459,
    "Tl216": 216.015964,
    "Pb216": 216.008062,
    "Bi216": 216.006305985,
    "Po216": 216.001913416,
    "At216": 216.002422643,
    "Rn216": 216.000271942,
    "Fr216": 216.003189523,
    "Ra216": 216.003533534,
    "Ac216": 216.008749101,
    "Th216": 216.011055933,
    "Pa216": 216.019134633,
    "U216": 216.024762829,
    "Tl217": 217.020032,
    "Pb217": 217.013162,
    "Bi217": 217.009372,
    "Po217": 217.006316145,
    "At217": 217.004717794,
    "Rn217": 217.003927632,
    "Fr217": 217.00463198,
    "Ra217": 217.006322676,
    "Ac217": 217.009342325,
    "Th217": 217.013103443,
    "Pa217": 217.018309024,
    "U217": 217.02466,
    "Tl218": 218.025454,
    "Pb218": 218.016779,
    "Bi218": 218.014188,
    "Po218": 218.008971234,
    "At218": 218.008695941,
    "Rn218": 218.005601123,
    "Fr218": 218.00757862,
    "Ra218": 218.007134297,
    "Ac218": 218.01164886,
    "Th218": 218.013276248,
    "Pa218": 218.020021133,
    "U218": 218.023504877,
    "Pb219": 219.022136,
    "Bi219": 219.01752,
    "Po219": 219.013614,
    "At219": 219.011160587,
    "Rn219": 219.009478683,
    "Fr219": 219.009250664,
    "Ra219": 219.010084715,
    "Ac219": 219.012420425,
    "Th219": 219.015526432,
    "Pa219": 219.019949909,
    "U219": 219.025009233,
    "Np219": 219.031601865,
    "Pb220": 220.025905,
    "Bi220": 220.022501,
    "Po220": 220.016386,
    "At220": 220.015433,
    "Rn220": 220.011392443,
    "Fr220": 220.012326789,
    "Ra220": 220.011027542,
    "Ac220": 220.014754527,
    "Th220": 220.015769866,
    "Pa220": 220.021769753,
    "U220": 220.024706,
    "Np220": 220.03271628,
    "Bi221": 221.02598,
    "Po221": 221.021228,
    "At221": 221.018017,
    "Rn221": 221.015535637,
    "Fr221": 221.014253714,
    "Ra221": 221.013917293,
    "Ac221": 221.015599721,
    "Th221": 221.018185757,
    "Pa221": 221.021873393,
    "U221": 221.026323297,
    "Np221": 221.03211,
    "Pu221": 221.038572,
    "Bi222": 222.031079,
    "Po222": 222.02414,
    "At222": 222.022494,
    "Rn222": 222.017576017,
    "Fr222": 222.017582615,
    "Ra222": 222.015373371,
    "Ac222": 222.017844232,
    "Th222": 222.01846822,
    "Pa222": 222.023687064,
    "U222": 222.026057957,
    "Np222": 222.033574706,
    "Pu222": 222.037638,
    "Bi223": 223.034611,
    "Po223": 223.02907,
    "At223": 223.025151,
    "Rn223": 223.021889283,
    "Fr223": 223.019734241,
    "Ra223": 223.018500648,
    "Ac223": 223.019135982,
    "Th223": 223.020811083,
    "Pa223": 223.023980414,
    "U223": 223.027960754,
    "Np223": 223.03291334,
    "Pu223": 223.038777,
    "Am223": 223.04584,
    "Bi224": 224.039796,
    "Po224": 224.03211,
    "At224": 224.029749,
    "Rn224": 224.024095803,
    "Fr224": 224.023348096,
    "Ra224": 224.020210361,
    "Ac224": 224.021722249,
    "Th224": 224.021466137,
    "Pa224": 224.025617286,
    "U224": 224.027635913,
    "Np224": 224.03438803,
    "Pu224": 224.037875,
    "Am224": 224.046442,
    "Po225": 225.037123,
    "At225": 225.032528,
    "Rn225": 225.028485572,
    "Fr225": 225.025572466,
    "Ra225": 225.023610502,
    "Ac225": 225.023228601,
    "Th225": 225.023950975,
    "Pa225": 225.026147927,
    "U225": 225.02938505,
    "Np225": 225.033943422,
    "Pu225": 225.03897,
    "Am225": 225.045508,
    "Po226": 226.04031,
    "At226": 226.037209,
    "Rn226": 226.03086138,
    "Fr226": 226.029544512,
    "Ra226": 226.025408186,
    "Ac226": 226.026096999,
    "Th226": 226.024903699,
    "Pa226": 226.027948217,
    "U226": 226.029338669,
    "Np226": 226.035230364,
    "Pu226": 226.03825,
    "Am226": 226.04613,
    "Po227": 227.04539,
    "At227": 227.040183,
    "Rn227": 227.035304393,
    "Fr227": 227.031865413,
    "Ra227": 227.029176205,
    "Ac227": 227.027750594,
    "Th227": 227.027702546,
    "Pa227": 227.028803586,
    "U227": 227.031181124,
    "Np227": 227.034975012,
    "Pu227": 227.039474,
    "Am227": 227.045282,
    "At228": 228.04496,
    "Rn228": 228.037835415,
    "Fr228": 228.035839433,
    "Ra228": 228.031068574,
    "Ac228": 228.031019685,
    "Th228": 228.028739741,
    "Pa228": 228.031050758,
    "U228": 228.031368959,
    "Np228": 228.036313,
    "Pu228": 228.038763325,
    "Am228": 228.046001,
    "At229": 229.048191,
    "Rn229": 229.042257272,
    "Fr229": 229.038291443,
    "Ra229": 229.034956703,
    "Ac229": 229.032947,
    "Th229": 229.031761357,
    "Pa229": 229.032095585,
    "U229": 229.033505976,
    "Np229": 229.036287269,
    "Pu229": 229.040145099,
    "Am229": 229.045282534,
    "Rn230": 230.045271,
    "Fr230": 230.042390787,
    "Ra230": 230.037054776,
    "Ac230": 230.036327,
    "Th230": 230.033132267,
    "Pa230": 230.034539717,
    "U230": 230.033940114,
    "Np230": 230.03782806,
    "Pu230": 230.039648313,
    "Am230": 230.046025,
    "Rn231": 231.049973,
    "Fr231": 231.045175353,
    "Ra231": 231.041027085,
    "Ac231": 231.038393,
    "Th231": 231.036302764,
    "Pa231": 231.0358825,
    "U231": 231.03629218,
    "Np231": 231.038243598,
    "Pu231": 231.041125946,
    "Am231": 231.045529,
    "Cm231": 231.050746,
    "Fr232": 232.049461219,
    "Ra232": 232.043475267,
    "Ac232": 232.042034,
    "Th232": 232.038053606,
    "Pa232": 232.038590205,
    "U232": 232.037154765,
    "Np232": 232.040107,
    "Pu232": 232.041182133,
    "Am232": 232.046613,
    "Cm232": 232.04974,
    "Fr233": 233.052517833,
    "Ra233": 233.04759457,
    "Ac233": 233.044346,
    "Th233": 233.041580126,
    "Pa233": 233.040246535,
    "U233": 233.039634294,
    "Np233": 233.040739421,
    "Pu233": 233.042997411,
    "Am233": 233.046468,
    "Cm233": 233.050771485,
    "Bk233": 233.056652,
    "Ra234": 234.0503821,
    "Ac234": 234.048139,
    "Th234": 234.043599801,
    "Pa234": 234.043305555,
    "U234": 234.040950296,
    "Np234": 234.042893245,
    "Pu234": 234.043317489,
    "Am234": 234.047731,
    "Cm234": 234.050158568,
    "Bk234": 234.057322,
    "Ra235": 235.05489,
    "Ac235": 235.05084,
    "Th235": 235.047255,
    "Pa235": 235.045399,
    "U235": 235.043928117,
    "Np235": 235.044061518,
    "Pu235": 235.045284609,
    "Am235": 235.047906478,
    "Cm235": 235.051545,
    "Bk235": 235.056651,
    "Ac236": 236.054988,
    "Th236": 236.049657,
    "Pa236": 236.048668,
    "U236": 236.04556613,
    "Np236": 236.046568296,
    "Pu236": 236.046056661,
    "Am236": 236.049427,
    "Cm236": 236.051372112,
    "Bk236": 236.057479,
    "Ac237": 237.057993,
    "Th237": 237.053629,
    "Pa237": 237.051023,
    "U237": 237.048728309,
    "Np237": 237.04817164,
    "Pu237": 237.048407888,
    "Am237": 237.049995,
    "Cm237": 237.052868988,
    "Bk237": 237.057123,
    "Cf237": 237.062199272,
    "Th238": 238.056388,
    "Pa238": 238.054637,
    "U238": 238.050786936,
    "Np238": 238.050944603,
    "Pu238": 238.049558175,
    "Am238": 238.051982531,
    "Cm238": 238.053081606,
    "Bk238": 238.058204,
    "Cf238": 238.06149,
    "Th239": 239.060655,
    "Pa239": 239.05726,
    "U239": 239.054291989,
    "Np239": 239.052937538,
    "Pu239": 239.052161596,
    "Am239": 239.053022729,
    "Cm239": 239.054908519,
    "Bk239": 239.058239,
    "Cf239": 239.062482,
    "Es239": 239.06831,
    "Pa240": 240.061203,
    "U240": 240.056592411,
    "Np240": 240.056163778,
    "Pu240": 240.05381174,
    "Am240": 240.055298374,
    "Cm240": 240.055528233,
    "Bk240": 240.059758,
    "Cf240": 240.062253447,
    "Es240": 240.068949,
    "Pa241": 241.064134,
    "U241": 241.06033,
    "Np241": 241.058309671,
    "Pu241": 241.056849651,
    "Am241": 241.056827343,
    "Cm241": 241.057651218,
    "Bk241": 241.060098,
    "Cf241": 241.06369,
    "Es241": 241.068592,
    "Fm241": 241.074311,
    "U242": 242.062931,
    "Np242": 242.061639548,
    "Pu242": 242.058740979,
    "Am242": 242.059547358,
    "Cm242": 242.058834187,
    "Bk242": 242.061999,
    "Cf242": 242.063754544,
    "Es242": 242.069567,
    "Fm242": 242.07343,
    "U243": 243.067075,
    "Np243": 243.064204,
    "Pu243": 243.062002068,
    "Am243": 243.061379889,
    "Cm243": 243.061387329,
    "Bk243": 243.063005905,
    "Cf243": 243.065475,
    "Es243": 243.069508,
    "Fm243": 243.074414,
    "Np244": 244.067891,
    "Pu244": 244.064204401,
    "Am244": 244.064282892,
    "Cm244": 244.062750622,
    "Bk244": 244.065178969,
    "Cf244": 244.065999447,
    "Es244": 244.070881,
    "Fm244": 244.074036,
    "Md244": 244.081157,
    "Np245": 245.070693,
    "Pu245": 245.067824554,
    "Am245": 245.066452827,
    "Cm245": 245.065491047,
    "Bk245": 245.066359814,
    "Cf245": 245.068046755,
    "Es245": 245.071192,
    "Fm245": 245.075354,
    "Md245": 245.080864,
    "Pu246": 246.070204172,
    "Am246": 246.069774,
    "Cm246": 246.067222016,
    "Bk246": 246.0686713,
    "Cf246": 246.068803685,
    "Es246": 246.072806474,
    "Fm246": 246.075353334,
    "Md246": 246.081713,
    "Pu247": 247.0743,
    "Am247": 247.072092,
    "Cm247": 247.070352678,
    "Bk247": 247.070305889,
    "Cf247": 247.070971348,
    "Es247": 247.073621929,
    "Fm247": 247.076944,
    "Md247": 247.08152,
    "Am248": 248.075752,
    "Cm248": 248.072349086,
    "Bk248": 248.073141689,
    "Cf248": 248.072182905,
    "Es248": 248.075469,
    "Fm248": 248.077185451,
    "Md248": 248.082607,
    "No248": 248.086623,
    "Am249": 249.07848,
    "Cm249": 249.075953992,
    "Bk249": 249.074983118,
    "Cf249": 249.074850428,
    "Es249": 249.076409,
    "Fm249": 249.078926042,
    "Md249": 249.082857155,
    "No249": 249.087802,
    "Cm250": 250.078357541,
    "Bk250": 250.078317195,
    "Cf250": 250.076404494,
    "Es250": 250.078611,
    "Fm250": 250.079519765,
    "Md250": 250.084164934,
    "No250": 250.087565,
    "Cm251": 251.082284988,
    "Bk251": 251.080760555,
    "Cf251": 251.079587171,
    "Es251": 251.079991431,
    "Fm251": 251.08154513,
    "Md251": 251.084774287,
    "No251": 251.088942,
    "Lr251": 251.094289,
    "Cm252": 252.08487,
    "Bk252": 252.08431,
    "Cf252": 252.081626507,
    "Es252": 252.082979173,
    "Fm252": 252.082466019,
    "Md252": 252.086385,
    "No252": 252.08896607,
    "Lr252": 252.095048,
    "Bk253": 253.08688,
    "Cf253": 253.085133723,
    "Es253": 253.084821241,
    "Fm253": 253.085180945,
    "Md253": 253.087143,
    "No253": 253.09056278,
    "Lr253": 253.09503385,
    "Rf253": 253.100528,
    "Bk254": 254.0906,
    "Cf254": 254.087323575,
    "Es254": 254.088024337,
    "Fm254": 254.086852424,
    "Md254": 254.08959,
    "No254": 254.090954211,
    "Lr254": 254.096238813,
    "Rf254": 254.100055,
    "Cf255": 255.091046,
    "Es255": 255.090273504,
    "Fm255": 255.089963495,
    "Md255": 255.091081702,
    "No255": 255.093196439,
    "Lr255": 255.096562399,
    "Rf255": 255.101267,
    "Db255": 255.106919,
    "Cf256": 256.093442,
    "Es256": 256.093597,
    "Fm256": 256.091771699,
    "Md256": 256.093888,
    "No256": 256.094281912,
    "Lr256": 256.098494024,
    "Rf256": 256.101151464,
    "Db256": 256.107674,
    "Es257": 257.095979,
    "Fm257": 257.095105419,
    "Md257": 257.095537343,
    "No257": 257.096884203,
    "Lr257": 257.09948,
    "Rf257": 257.102916796,
    "Db257": 257.107520042,
    "Es258": 258.09952,
    "Fm258": 258.097077,
    "Md258": 258.098433634,
    "No258": 258.098205,
    "Lr258": 258.101753,
    "Rf258": 258.103429895,
    "Db258": 258.108972995,
    "Sg258": 258.11304,
    "Fm259": 259.100596,
    "Md259": 259.100445,
    "No259": 259.100998364,
    "Lr259": 259.1029,
    "Rf259": 259.105601,
    "Db259": 259.109491859,
    "Sg259": 259.114353,
    "Fm260": 260.102809,
    "Md260": 260.10365,
    "No260": 260.102641,
    "Lr260": 260.105504,
    "Rf260": 260.10644,
    "Db260": 260.111297,
    "Sg260": 260.114383435,
    "Bh260": 260.121443,
    "Md261": 261.105828,
    "No261": 261.105696,
    "Lr261": 261.106879,
    "Rf261": 261.108769591,
    "Db261": 261.111979,
    "Sg261": 261.115948135,
    "Bh261": 261.121395733,
    "Md262": 262.109144,
    "No262": 262.107463,
    "Lr262": 262.109615,
    "Rf262": 262.109923,
    "Db262": 262.114067,
    "Sg262": 262.116338978,
    "Bh262": 262.122654688,
    "No263": 263.110714,
    "Lr263": 263.111293,
    "Rf263": 263.112461,
    "Db263": 263.114987,
    "Sg263": 263.118299,
    "Bh263": 263.122916,
    "Hs263": 263.128479,
    "No264": 264.112734,
    "Lr264": 264.114198,
    "Rf264": 264.113876,
    "Db264": 264.117297,
    "Sg264": 264.11893,
    "Bh264": 264.124486,
    "Hs264": 264.12835633,
    "Lr265": 265.116193,
    "Rf265": 265.116683,
    "Db265": 265.1185,
    "Sg265": 265.121089,
    "Bh265": 265.124955,
    "Hs265": 265.129791744,
    "Mt265": 265.135937,
    "Lr266": 266.119874,
    "Rf266": 266.118236,
    "Db266": 266.121032,
    "Sg266": 266.121973,
    "Bh266": 266.12679,
    "Hs266": 266.130048783,
    "Mt266": 266.137062253,
    "Rf267": 267.121787,
    "Db267": 267.122399,
    "Sg267": 267.124323,
    "Bh267": 267.127499,
    "Hs267": 267.131678,
    "Mt267": 267.137189,
    "Ds267": 267.143726,
    "Rf268": 268.123968,
    "Db268": 268.125669,
    "Sg268": 268.125389,
    "Bh268": 268.129584,
    "Hs268": 268.132011,
    "Mt268": 268.138649,
    "Ds268": 268.143477,
    "Db269": 269.127911,
    "Sg269": 269.128495,
    "Bh269": 269.130411,
    "Hs269": 269.133649,
    "Mt269": 269.138809,
    "Ds269": 269.144750965,
    "Db270": 270.131399,
    "Sg270": 270.130362,
    "Bh270": 270.133366,
    "Hs270": 270.134313,
    "Mt270": 270.140322,
    "Ds270": 270.14458662,
    "Sg271": 271.133782,
    "Bh271": 271.135115,
    "Hs271": 271.137082,
    "Mt271": 271.140741,
    "Ds271": 271.145951,
    "Sg272": 272.135825,
    "Bh272": 272.138259,
    "Hs272": 272.138492,
    "Mt272": 272.143298,
    "Ds272": 272.146091,
    "Rg272": 272.153273,
    "Sg273": 273.139475,
    "Bh273": 273.140294,
    "Hs273": 273.141458,
    "Mt273": 273.144695,
    "Ds273": 273.148455,
    "Rg273": 273.153393,
    "Bh274": 274.143599,
    "Hs274": 274.143217,
    "Mt274": 274.147343,
    "Ds274": 274.149434,
    "Rg274": 274.155247,
    "Bh275": 275.145766,
    "Hs275": 275.14653,
    "Mt275": 275.148972,
    "Ds275": 275.152085,
    "Rg275": 275.156088,
    "Bh276": 276.149169,
    "Hs276": 276.148348,
    "Mt276": 276.151705,
    "Ds276": 276.153022,
    "Rg276": 276.158226,
    "Cn276": 276.161418,
    "Bh277": 277.151477,
    "Hs277": 277.151772,
    "Mt277": 277.153525,
    "Ds277": 277.155763,
    "Rg277": 277.159322,
    "Cn277": 277.163535,
    "Bh278": 278.154988,
    "Hs278": 278.153753,
    "Mt278": 278.156487,
    "Ds278": 278.157007,
    "Rg278": 278.16159,
    "Cn278": 278.164083,
    "Nh278": 278.170725,
    "Hs279": 279.157274,
    "Mt279": 279.158439,
    "Ds279": 279.159984,
    "Rg279": 279.16288,
    "Cn279": 279.166422,
    "Nh279": 279.171187,
    "Hs280": 280.159335,
    "Mt280": 280.161579,
    "Ds280": 280.161375,
    "Rg280": 280.165204,
    "Cn280": 280.167102,
    "Nh280": 280.173098,
    "Mt281": 281.163608,
    "Ds281": 281.164545,
    "Rg281": 281.166757,
    "Cn281": 281.169563,
    "Nh281": 281.17371,
    "Mt282": 282.166888,
    "Ds282": 282.166174,
    "Rg282": 282.169343,
    "Cn282": 282.170507,
    "Nh282": 282.17577,
    "Ds283": 283.169437,
    "Rg283": 283.171101,
    "Cn283": 283.173202,
    "Nh283": 283.176666,
    "Ds284": 284.171187,
    "Rg284": 284.173882,
    "Cn284": 284.17436,
    "Nh284": 284.178843,
    "Fl284": 284.181192,
    "Rg285": 285.175771,
    "Cn285": 285.177227,
    "Nh285": 285.180106,
    "Fl285": 285.183503,
    "Rg286": 286.178756,
    "Cn286": 286.178691,
    "Nh286": 286.182456,
    "Fl286": 286.184226,
    "Cn287": 287.181826,
    "Nh287": 287.184064,
    "Fl287": 287.18672,
    "Mc287": 287.19082,
    "Cn288": 288.183501,
    "Nh288": 288.186764,
    "Fl288": 288.187781,
    "Mc288": 288.192879,
    "Nh289": 289.188461,
    "Fl289": 289.190517,
    "Mc289": 289.193971,
    "Lv289": 289.198023,
    "Nh290": 290.191429,
    "Fl290": 290.191875,
    "Mc290": 290.196235,
    "Lv290": 290.198635,
    "Fl291": 291.194848,
    "Mc291": 291.197725,
    "Lv291": 291.201014,
    "Ts291": 291.205748,
    "Mc292": 292.200323,
    "Lv292": 292.201969,
    "Ts292": 292.207861,
    "Lv293": 293.204583,
    "Ts293": 293.208727,
    "Og293": 293.213423,
    "Ts294": 294.21084,
    "Og294": 294.213979,
    "Og295": 295.216178,
    "C0": 12.011115164865895,
    "Zn0": 65.3777822949742,
    "Pt0": 195.0844293345695,
    "Os0": 190.22486144914382,
    "Tl0": 204.38333226812722,
}
